@@ -61,6 +61,7 @@ class Source :
 		self.ACLASS_LIST = ['String']
 		self.ICLASS_LIST = ['String']
 		self.XCLASS_LIST = ['String:urn']
+		self.GENERICS_LIST = []
 		self.XPACKAGE_LIST = []
 		self.INCLUDE_H = ['<konoha/class/konoha.h>']
 		self.STATICLIB_MAP = {}
@@ -115,7 +116,11 @@ class Source :
 			return
 		self.CLASS_MAP[c.id] = c
 		self.CLASS_LIST.append(c) 
-
+	
+	def add_generics(self, anno):
+		c = Generics(anno, self)
+		self.GENERICS_LIST.append(c) 
+	
 	def add_xclass(self, c):
 		if c.endswith("[]"):
 			c = c.replace("[]", "")
@@ -280,6 +285,26 @@ class Class :
 	###
 ######
 
+###
+
+
+# /* @generics HashMapSS HashMap<String,String> String String */
+# /* @generics ArrayCmp int(Any1!,Any1!) Int! Any1! Any1! void */
+
+class Generics :
+	def __init__(self, anno, data):
+		self.anno = anno
+		t = anno.split()
+		self.cname = t[1]
+		self.fullname = t[2]
+		self.params = t[3:]
+		if self.fullname.find('(') > 0:
+			self.bname = 'Closure'
+		else: 
+			self.bname, dummy = self.fullname.split('<')
+	###
+######
+
 class Param :
 	def __init__(self, type, name, value = None):
 		self.set(type, name)
@@ -314,7 +339,6 @@ class Method :
 	def __init__(self, anno, functype, data):
 		self.anno = anno
 		self.functype = functype
-		
 		pre, args = anno.split('(')
 		t = pre.replace('..', ',,').replace('.',' ').split()
 		self.rtype = t[1].replace(',,', '..')
@@ -498,7 +522,7 @@ def nz_cparam(tn, vn):
 ###
 
 def parse_funcname(functype):
-	t = functype.replace('(', ' ').split()
+	t = functype.replace('static', '').replace('(', ' ').split()
 	tn, funcname = nz_cparam(t[0], t[1])
 	return funcname
 ###
@@ -526,7 +550,24 @@ def parse_flag(anno, oplist):
 def read_source_cblock(fpath, zone, text, data):
 	if text.find('@data') > 0 : return
 	functype = parse_functype(text)
-	if functype == None or functype.find('static') >= 0: 
+	if functype == None : 
+		if functype != None and functype.find('_fdefault') > 0 :
+			funcname = parse_funcname(functype)
+			data.FUNC_MAP[funcname] = functype
+		return
+	
+	if 'KNHINIT' in functype:
+		functype = functype.replace('KNHINIT', '')
+		funcname = parse_funcname(functype)
+		data.INITFUNC_LIST.append(funcname)
+	else:
+		funcname = parse_funcname(functype)
+
+	for ln in text.split('\n'):
+		if ln.find('/* @map') != -1: data.add_mapper(parse_anno(ln, '@map'), funcname, text)
+		if ln.find('/* @method') != -1: data.add_method(parse_anno(ln, '@method'), functype, text)
+	
+	if functype.find('static') >= 0: 
 		if functype != None and functype.find('_fdefault') > 0 :
 			funcname = parse_funcname(functype)
 			data.FUNC_MAP[funcname] = functype
@@ -537,16 +578,8 @@ def read_source_cblock(fpath, zone, text, data):
 		data.PROTOTYPE_LIST.append('/* %s */' % fpath)
 	
 	data.PROTOTYPE_LIST.append(functype + ';')
-	if 'KNHINIT' in functype:
-		functype = functype.replace('KNHINIT', '')
-		funcname = parse_funcname(functype)
-		data.INITFUNC_LIST.append(funcname)
-	else:
-		funcname = parse_funcname(functype)
 	data.FUNC_MAP[funcname] = functype
 	
-	if text.find('/* @map') != -1: data.add_mapper(parse_anno(text, '@map'), funcname, text)
-	if text.find('/* @method') != -1: data.add_method(parse_anno(text, '@method'), functype, text)
 	
 ###
 
@@ -563,9 +596,13 @@ def read_lineanno(line, data):
 	if line.find('/* @expt') != -1: 
 		data.add_expt(parse_anno(line, '@expt'))
 		return line
+	if line.find('/* @generics') != -1: 
+		data.add_generics(parse_anno(line, '@generics'))
+		return line
 	return line
 
 def read_source_h(fpath, data):
+	print fpath
 	f = open(fpath)
 	__FILE__ = fpath
 	__LINE__ = 1
