@@ -200,6 +200,7 @@ typedef struct knh_Range_t {
 /* ------------------------------------------------------------------------ */
 /* @class Array Object knh_Array_t @Cyclic @Param1 */
 /* @flag Array.Dim ARY:1 (%s)->h.flag 'is:set:*:*' */
+/* @generics ArrayCmp int(Any1!,Any1!) Int! Any1! Any1! void */
 
 #define KNH_ARRAY_INITSIZE  (KNH_FASTMALLOC_SIZE / sizeof(knh_Object_t*))
 
@@ -265,6 +266,8 @@ typedef struct knh_Iterator {
 /* @class DictSet Object knh_DictSet_t @Cyclic @Param1 */
 /* @flag DictSet.IgnoreCase DICTS:1 (%s)->h.flag 'is:set:is:*' */
 
+#define KNH_DICT_INITSIZE (KNH_FASTMALLOC_SIZE/(sizeof(void*)*2))
+
 typedef int (*knh_fbytescmp)(knh_bytes_t, knh_bytes_t);
 
 typedef struct knh_dict_t {
@@ -332,6 +335,7 @@ typedef struct {
 /* @class HashMap Object knh_HashMap_struct @Param2 */
 /* @class HashSet Object knh_HashSet_struct @Param1 */
 
+#define KNH_HASH_INITSIZE 83
 #define KNH_HASH_TABLESIZE  KONOHA_PAGESIZE
 #define KNH_HASHENTRY(T,ESIZE,i)  (knh_hashentry_t*)&((T)[(ESIZE) * (i)])
 
