@@ -230,6 +230,9 @@ typedef struct knh_Asm {
 	struct knh_Bytes_t* elf;
 	struct knh_Bytes_t* dwarf;
 	knh_kode_t         *prev_op;
+
+	struct knh_Array_t *constPools;
+	struct knh_Array_t *exportsMethods;
 } knh_Asm_struct;
 
 
