@@ -1,7 +1,7 @@
 /****************************************************************************
  * KONOHA COPYRIGHT, LICENSE NOTICE, AND DISCRIMER  
  * 
- * Copyright (c) 2005-2008, Kimio Kuramitsu <kimio at ynu.ac.jp>
+ * Copyright (c) 2005-2009, Kimio Kuramitsu <kimio at ynu.ac.jp>
  *           (c) 2008-      Konoha Software Foundation  
  * All rights reserved.
  * 
@@ -194,6 +194,7 @@ KNHAPI(void) knh_Bytes_putc(Ctx *ctx, Bytes *o, int ch);
 KNHAPI(void) knh_Bytes_write(Ctx *ctx, Bytes *o, knh_bytes_t v);
 KNHAPI(knh_bytes_t) new_bytes(char *c);
 KNHAPI(knh_bytes_t) new_bytes__2(char *buf, size_t len);
+KNHAPI(int) knh_bytes_indexOf(knh_bytes_t base, knh_bytes_t delim);
 KNHAPI(int) knh_bytes_strcmp(knh_bytes_t v1, knh_bytes_t v2);
 KNHAPI(int) knh_bytes_strcasecmp(knh_bytes_t v1, knh_bytes_t v2);
 KNHAPI(knh_bool_t) knh_bytes_equals(knh_bytes_t v1, knh_bytes_t v2);
@@ -251,15 +252,16 @@ KNHAPI(void) konoha_addIODriver(Ctx *ctx, char *alias, knh_iodrv_t *d);
 KNHAPI(void) konoha_addRegexDriver(Ctx *ctx, char *alias, knh_regex_drvapi_t *d);
 KNHAPI(int) knh_System_hasLibrary(Ctx *ctx, char *libname, char *funcname);
 KNHAPI(void) konoha_addClassSpecFunc(Ctx *ctx, char *urn, f_makespec func);
+KNHAPI(Ctx*) konoha_getCurrentContext(void);
 KNHAPI(int) konoha_parseopt(konoha_t konoha, int argc, char **argv);
 KNHAPI(char*) konoha_eval(konoha_t konoha, char *script);
+KNHAPI(void) konoha_readFile(Ctx *ctx, char *fpath);
 KNHAPI(void) konoha_read(konoha_t konoha, char *fpath);
 KNHAPI(int) konoha_main(konoha_t konoha, int argc, char **argv);
 KNHAPI(void) konoha_shell(konoha_t konoha);
 KNHAPI(char*) knh_format_ospath(Ctx *ctx, char *buf, size_t bufsiz, knh_bytes_t path);
 KNHAPI(void) konoha_SETv(Ctx *ctx, Object **v, Object *o);
 KNHAPI(void) konoha_FINALv(Ctx *ctx, Object **v);
-KNHAPI_(Object*) knh_boxing(Ctx *ctx, knh_sfp_t *sfp, knh_class_t cid);
 KNHAPI(knh_class_t) konoha_addClass(Ctx *ctx, knh_flag_t flag, char *name, int method_size);
 KNHAPI(knh_class_t) konoha_addVirtualClass(Ctx *ctx, char *name, int method_size);
 KNHAPI(knh_class_t) konoha_addNaitiveClass(Ctx *ctx, char *name, int method_size);
@@ -273,15 +275,17 @@ KNHAPI(void) konoha_addFloatConst(Ctx *ctx, char *name, knh_float_t value);
 KNHAPI(void) konoha_addStringConst(Ctx *ctx, char *name, char *text);
 KNHAPI(void) konoha_addDriver(Ctx *ctx, char *name, int type, void *drv);
 KNHAPI(char*) KNH_SAFEFILE(char *file);
+KNHAPI_(Object*) knh_boxing(Ctx *ctx, knh_sfp_t *sfp, knh_class_t cid);
 KNHAPI_(void) knh_sfp_boxing(Ctx *ctx, knh_sfp_t *sfp);
 KNHAPI_(void) knh_sfp_unboxing(Ctx *ctx, knh_sfp_t *sfp);
-KNHAPI(void) knh_sfp_sformat(Ctx *ctx, knh_sfp_t *sfp, Method *mtd, OutputStream *w, Any *m);
+KNHAPI(void) knh_sfp_sformat(Ctx *ctx, knh_sfp_t *lsfp, Method *mtd, OutputStream *w, Any *m);
 KNHAPI(void) knh_sfp_format(Ctx *ctx, knh_sfp_t *sfp, knh_methodn_t mn, OutputStream *w, Any *m);
 KNHAPI(void) knh_throw_TODO(Ctx *ctx, char *file, int line, char *func);
 KNHAPI(char*) konoha_doing(Ctx *ctx, char *msg);
 KNHAPI(void) knh_throwException(Ctx *ctx, Exception *e, char *file, int line);
 KNHAPI(void) knh_throw__s(Ctx *ctx, char *msg, char *file, int line);
 KNHAPI(void) knh_throw(Ctx *ctx, Object *e, char *file, int line);
+KNHAPI(void) konoha_throwSecurityException(void);
 KNHAPI(konoha_t) konoha_open(size_t ctxsize, size_t stacksize);
 KNHAPI(void) konoha_close(konoha_t konoha);
 
