@@ -1,7 +1,7 @@
 /****************************************************************************
  * KONOHA COPYRIGHT, LICENSE NOTICE, AND DISCRIMER  
  * 
- * Copyright (c) 2005-2008, Kimio Kuramitsu <kimio at ynu.ac.jp>
+ * Copyright (c) 2005-2009, Kimio Kuramitsu <kimio at ynu.ac.jp>
  *           (c) 2008-      Konoha Software Foundation  
  * All rights reserved.
  * 
@@ -40,306 +40,38 @@ extern "C" {
 /* ======================================================================== */
 /* [PROTOTYPE] */
 /* ../src/api/arrayapi.c */
-METHOD knh__Array_new(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_new__array(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_new__init(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__IArray_new(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__IArray_new__array(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__IArray_new__init(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__FArray_new(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__FArray_new__array(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__FArray_new__init(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_add(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_opLshift(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__IArray_add(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__IArray_opLshift(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__FArray_add(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__FArray_opLshift(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_opSize(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_get(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__IArray_get(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__FArray_get(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_set(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__IArray_set(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__FArray_set(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_setAll(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_opSubset(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_opSubsete(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_opOffset(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_insert(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_remove(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_pop(Ctx *ctx, knh_sfp_t *sfp);
 void knh_Array_clear(Ctx *ctx, Array *o);
-METHOD knh__Array_indexOf(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_lastIndexOf(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_opHas(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_sort(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_reverse(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_swap(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_shuffle(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__IArray_sort(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__IArray_reverse(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__IArray_swap(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__IArray_shuffle(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__FArray_sort(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__FArray_reverse(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__FArray_swap(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__FArray_shuffle(Ctx *ctx, knh_sfp_t *sfp);
 void knh_Array__k(Ctx *ctx, Array *o, OutputStream *w, String *m);
 MAPPER knh_Array_Iterator(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_opItr(Ctx *ctx, knh_sfp_t *sfp);
 MAPPER knh_Iterator_Array(Ctx *ctx, knh_sfp_t *sfp);
 Mapper *knh_tMapper_newIteratorArray(Ctx *ctx, knh_class_t icid, knh_class_t acid);
 Mapper *knh_tMapper_newArrayIterator(Ctx *ctx, knh_class_t acid, knh_class_t icid);
 void knh_array_dfree(Ctx *ctx, void *ptr, size_t capacity, size_t usize);
-METHOD knh__Array_new__array2D(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_new__array3D(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_get2D(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_get3D(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_set2D(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Array_set3D(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__IArray_new__array2D(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__IArray_new__array3D(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__IArray_get2D(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__IArray_get3D(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__IArray_set2D(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__IArray_set3D(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__FArray_new__array2D(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__FArray_new__array3D(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__FArray_get2D(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__FArray_get3D(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__FArray_set2D(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__FArray_set3D(Ctx *ctx, knh_sfp_t *sfp);
-/* ../src/api/bytes.c */
-METHOD knh__Bytes_new(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Bytes_putc(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Bytes_write(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Bytes_opLshift(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Bytes_opSize(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Bytes_get(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Bytes_set(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Bytes_opFill(Ctx *ctx, knh_sfp_t *sfp);
-void knh_Bytes__dump(Ctx *ctx, Bytes *o, OutputStream *w, String *m);
-MAPPER knh_Bytes_String(Ctx *ctx, knh_sfp_t *sfp);
-MAPPER knh_String_Bytes(Ctx *ctx, knh_sfp_t *sfp);
-/* ../src/api/dictapi.c */
-METHOD knh__DictMap_new(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_new__init(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_get(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_opHas(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_set(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_remove(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_clear(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_opSize(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_opLshift(Ctx *ctx, knh_sfp_t *sfp);
-MAPPER knh_DictMap_Iterator(Ctx *ctx, knh_sfp_t *sfp);
-MAPPER knh_DictMap_Iterator__(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictMap_opItr(Ctx *ctx, knh_sfp_t *sfp);
-void knh_DictMap__k(Ctx *ctx, DictMap *o, OutputStream *w, String *m);
-METHOD knh__DictSet_new(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictSet_add(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictSet_get(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictSet_opHas(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictSet_set(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictSet_remove(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictSet_clear(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictSet_opSize(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictSet_opLshift(Ctx *ctx, knh_sfp_t *sfp);
-MAPPER knh_DictSet_Iterator(Ctx *ctx, knh_sfp_t *sfp);
-MAPPER knh_DictSet_String__(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__DictSet_opItr(Ctx *ctx, knh_sfp_t *sfp);
-MAPPER knh_String___DictSet(Ctx *ctx, knh_sfp_t *sfp);
-void knh_DictSet__k(Ctx *ctx, DictSet *o, OutputStream *w, String *m);
-void knh_DictSet__dump(Ctx *ctx, DictSet *o, OutputStream *w, String *m);
-/* ../src/api/exception.c */
-METHOD knh__Exception_new(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Exception_opIsa(Ctx *ctx, knh_sfp_t *sfp);
-void knh_Exception__s(Ctx *ctx, Exception *o, OutputStream *w, String *m);
-void knh_Exception__k(Ctx *ctx, Exception *o, OutputStream *w, String *m);
-void knh_Exception__dump(Ctx *ctx, Exception *o, OutputStream *w, String *m);
+void knh_Iterator__k(Ctx *ctx, Iterator *o, OutputStream *w, String *m);
+void knh_Iterator__dump(Ctx *ctx, Iterator *o, OutputStream *w, String *m);
+/* ../src/api/dbapi.c */
+int knh_ResultSet_indexof_(Ctx *ctx, knh_sfp_t *sfp);
 /* ../src/api/hashapi.c */
-METHOD knh__HashMap_new(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__HashMap_get(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__HashMap_opHas(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__HashMap_remove(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__HashMap_set(Ctx *ctx, knh_sfp_t *sfp);
 void knh_HashMap__k(Ctx *ctx, knh_Hash_t *o, OutputStream *w, String *m);
 void knh_HashMap__dump(Ctx *ctx, HashMap *o, OutputStream *w, String *m);
 MAPPER knh_HashMap_Iterator(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__HashMap_opItr(Ctx *ctx, knh_sfp_t *sfp);
-/* ../src/api/iterator.c */
-void knh_Iterator__k(Ctx *ctx, Iterator *o, OutputStream *w, String *m);
-void knh_Iterator__dump(Ctx *ctx, Iterator *o, OutputStream *w, String *m);
-/* ../src/api/kdbcapi.c */
-METHOD knh__Connection_new(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Connection_query(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Connection_exec(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__ResultSet_opSize(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__ResultSet_getName(Ctx *ctx, knh_sfp_t *sfp);
-knh_integer_t knh_ResultSet_getInt(Ctx *ctx, ResultSet *o, size_t n);
-METHOD knh__ResultSet_getInt(Ctx *ctx, knh_sfp_t *sfp);
-knh_float_t knh_ResultSet_getFloat(Ctx *ctx, ResultSet *o, size_t n);
-METHOD knh__ResultSet_getFloat(Ctx *ctx, knh_sfp_t *sfp);
-String* knh_ResultSet_getString(Ctx *ctx, ResultSet *o, size_t n);
-METHOD knh__ResultSet_getString(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__ResultSet_get(Ctx *ctx, knh_sfp_t *sfp);
-void knh_ResultSet__dump(Ctx *ctx, ResultSet *o, OutputStream *w, String *m);
-/* ../src/api/numberapi.c */
-METHOD knh__Boolean_opNot(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opAdd(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opNeg(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opSub(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opMul(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opDiv(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opMod(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opEq(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opNeq(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opLt(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opLte(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opGt(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opGte(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opLand(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opLor(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opXor(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opLnot(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opLshift(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opRshift(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opNext(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opPrev(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_opSize(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int_random(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float_opAdd(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float_opNeg(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float_opSub(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float_opMul(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float_opDiv(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float_opEq(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float_opNeq(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float_opLt(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float_opLte(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float_opGt(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float_opGte(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float_opNext(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float_opPrev(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float_random(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float_opSize(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Boolean__s(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Boolean__k(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int__s(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int__k(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int__d(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int__u(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int__f(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int__x(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Int__bits(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float__s(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float__d(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float__f(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float__bits(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Float__k(Ctx *ctx, knh_sfp_t *sfp);
-MAPPER knh_Boolean_String(Ctx *ctx, knh_sfp_t *sfp);
-MAPPER knh_String_Boolean(Ctx *ctx, knh_sfp_t *sfp);
-MAPPER knh_String_Int(Ctx *ctx, knh_sfp_t *sfp);
-MAPPER knh_Int_String(Ctx *ctx, knh_sfp_t *sfp);
-MAPPER knh_String_Float(Ctx *ctx, knh_sfp_t *sfp);
-MAPPER knh_Float_String(Ctx *ctx, knh_sfp_t *sfp);
-MAPPER knh_Int_Float(Ctx *ctx, knh_sfp_t *sfp);
-MAPPER knh_Float_Int(Ctx *ctx, knh_sfp_t *sfp);
-void init_primitive(Ctx *ctx);
 /* ../src/api/objectapi.c */
-METHOD knh__Object_new__init(Ctx *ctx, knh_sfp_t *sfp);
-int knh_Object_compareTo(Ctx *ctx, Object *o1, Object *o2);
-knh_bool_t knh_Object_equals(Ctx *ctx, Object *o1, Object *o2);
-METHOD knh__Object_opEq(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Object_opNeq(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Object_opLt(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Object_opLte(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Object_opGt(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Object_opGte(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Object_opIs(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Object_opIsa(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Object_opTo(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Object_getClass(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Object_isNull(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Object_isNotNull(Ctx *ctx, knh_sfp_t *sfp);
-MAPPER knh_Object_Iterator(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Object_opItr(Ctx *ctx, knh_sfp_t *sfp);
-void knh_Object__s(Ctx *ctx, Object *b, OutputStream *w, String *m);
-void knh_Object__k(Ctx *ctx, Object *o, OutputStream *w, String *m);
-void knh_Object__dump(Ctx *ctx, Object *b, OutputStream *w, String *m);
-void knh_Object__empty(Ctx *ctx, Object *b, OutputStream *w, String *m);
-void knh_Object__addr(Ctx *ctx, Object *b, OutputStream *w, String *m);
-MAPPER knh_Object_String(Ctx *ctx, knh_sfp_t *sfp);
-void knh_Nue__s(Ctx *ctx, Nue *b, OutputStream *w, String *m);
-void knh_Nue__k(Ctx *ctx, Nue *b, OutputStream *w, String *m);
-void knh_Class__s(Ctx *ctx, Class *o, OutputStream *w, String *m);
-void knh_Class__k(Ctx *ctx, Class *o, OutputStream *w, String *m);
-void knh_Class__dump(Ctx *ctx, Class *o, OutputStream *w, String *m);
-void knh_Class__man(Ctx *ctx, Class *o, OutputStream *w, String *m);
 void knh_Method__s(Ctx *ctx, Method *o, OutputStream *w, String *m);
 void knh_Method__k(Ctx *ctx, Method *o, OutputStream *w, String *m);
 void knh_Method__dump(Ctx *ctx, Method *o, OutputStream *w, String *m);
 /* ../src/api/streamapi.c */
-METHOD knh__InputStream_new(Ctx *ctx, knh_sfp_t *sfp);
-void knh_InputStream_setEncoding(Ctx *ctx, InputStream *o, String *enc);
-METHOD knh__InputStream_isClosed(Ctx *ctx, knh_sfp_t *sfp);
-void knh_InputStream__dump(Ctx *ctx, InputStream *b, OutputStream *w, String *m);
-MAPPER knh_InputStream_String__(Ctx *ctx, knh_sfp_t *sfp);
-void knh_InputStream__k(Ctx *ctx, InputStream *o, OutputStream *w, String *m);
-METHOD knh__OutputStream_new(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__OutputStream_write(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__OutputStream_isClosed(Ctx *ctx, knh_sfp_t *sfp);
-void knh_OutputStream_setEncoding(Ctx *ctx, OutputStream *o, String *enc);
-METHOD knh__OutputStream_print(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__OutputStream_println(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__OutputStream_opLshift(Ctx *ctx, knh_sfp_t *sfp);
 void knh_OutputStream__k(Ctx *ctx, OutputStream *o, OutputStream *w, String *m);
+void knh_InputStream_setEncoding(Ctx *ctx, InputStream *o, String *enc);
+void knh_OutputStream_setEncoding(Ctx *ctx, OutputStream *o, String *enc);
 /* ../src/api/stringapi.c */
-knh_bool_t knh_String_equals(String *o, knh_bytes_t s);
-knh_bool_t knh_String_startsWith(String *b, knh_bytes_t s);
-knh_bool_t knh_String_endsWith(String *b, knh_bytes_t s);
-knh_index_t knh_bytes_indexOf(knh_bytes_t base, knh_bytes_t delim);
-METHOD knh__String_indexOf(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__String_opSize(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__String_opAdd(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__String_concat(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__String_opSub(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__String_replace(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__String_opMul(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__String_opFmt(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__String_opDiv(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__String_opMod(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__String_opHas(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__String_get(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__String_opOffset(Ctx *ctx, knh_sfp_t *sfp);
 size_t bconv__toLower(Ctx *ctx, BytesConv *o, knh_bytes_t t, knh_Bytes_t *ba);
-METHOD knh__String_toLower(Ctx *ctx, knh_sfp_t *sfp);
 size_t bconv__toUpper(Ctx *ctx, BytesConv *o, knh_bytes_t t, knh_Bytes_t *ba);
-METHOD knh__String_toUpper(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__String_trim(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__String_split(Ctx *ctx, knh_sfp_t *sfp);
-void knh_String__s(Ctx *ctx, String *b, OutputStream *w, String *m);
-void knh_String__k(Ctx *ctx, String *o, OutputStream *w, String *m);
 /* ../src/api/systemapi.c */
-METHOD knh__System_getIn(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__System_setIn(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__System_getOut(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__System_setOut(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__System_getErr(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__System_setErr(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__System_exit(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__System_hasDir(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__System_hasFile(Ctx *ctx, knh_sfp_t *sfp);
-void knh_System__k(Ctx *ctx, System *o, OutputStream *w, String *m);
-void knh_System__dump(Ctx *ctx, System *o, OutputStream *w, String *m);
 Object* knh_Context_getProperty(Ctx *ctx, Context *b, knh_bytes_t key);
 void knh_Context_setProperty(Ctx *ctx, Context *b, String *key, Any *value);
-METHOD knh__Context_listProperties(Ctx *ctx, knh_sfp_t *sfp);
+void knh_System__k(Ctx *ctx, System *o, OutputStream *w, String *m);
+void knh_System__dump(Ctx *ctx, System *o, OutputStream *w, String *m);
 void knh_Context_setEncoding(Ctx *ctx, knh_Context_t *o, String *enc);
-METHOD knh__Context_setIn(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Context_setOut(Ctx *ctx, knh_sfp_t *sfp);
-METHOD knh__Context_setErr(Ctx *ctx, knh_sfp_t *sfp);
-void knh_Context__dump(Ctx *ctx, Context *b, OutputStream *w, String *m);
 /* ../src/class/knh_AffineConv.c */
 AffineConv *new_AffineConv(Ctx *ctx, knh_float_t fa, knh_float_t fb);
 /* ../src/class/knh_Array.c */
@@ -410,6 +142,7 @@ char *knh_TYPEN(Ctx *ctx, knh_type_t type);
 METHOD knh__Closure_new(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Closure_invoke(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Closure_callcc(Ctx *ctx, knh_sfp_t *sfp);
+knh_class_t konoha_addClosureClass(Ctx *ctx, knh_class_t cid, String *name, knh_type_t r0, knh_type_t p1, knh_type_t p2, knh_type_t p3);
 knh_class_t knh_class_Closure(Ctx *ctx, knh_type_t r0, knh_type_t p1, knh_type_t p2, knh_type_t p3);
 knh_class_t knh_class_MethodClosure(Ctx *ctx, knh_class_t cid, Method *mtd);
 /* ../src/class/knh_Connection.c */
@@ -495,6 +228,8 @@ void knh_hashentry_collect(Ctx *ctx, knh_Hash_t *o, knh_hashentry_t *e);
 knh_hashentry_t *knh_hashentry_at(knh_Hash_t *o, size_t n);
 HashMap* new_HashMap(Ctx *ctx, char *name, size_t capacity);
 knh_hashentry_t *knh_Hash_get__hcode(Ctx *ctx, knh_Hash_t *o, knh_hcode_t hcode);
+Object *knh_HashMap_get__hcode(Ctx *ctx, HashMap *o, knh_hcode_t hcode);
+knh_uint_t knh_HashSet_get__hcode(Ctx *ctx, HashSet *o, knh_hcode_t hcode);
 void knh_Hash_remove__hcode(Ctx *ctx, knh_Hash_t *o, knh_hcode_t hcode);
 void knh_Hash_rehash(Ctx *ctx, knh_Hash_t *o);
 void knh_HashMap_set__hcode(Ctx *ctx, HashMap *o, knh_hcode_t hcode, Any *value);
@@ -573,6 +308,8 @@ Object *new_Nue(Ctx *ctx, String *msg);
 METHOD knh__Object_new(Ctx *ctx, knh_sfp_t *sfp);
 Object *knh_Object_copy(Ctx *ctx, Object *b);
 knh_hcode_t knh_Object_hashCode(Ctx *ctx, Object *o);
+int knh_Object_compareTo(Ctx *ctx, Object *o1, Object *o2);
+knh_bool_t knh_Object_equals(Ctx *ctx, Object *o1, Object *o2);
 knh_bytes_t knh_Object_tobytes(Ctx *ctx, Object *o);
 /* ../src/class/knh_OutputStream.c */
 Object *knh_OutputStream_open(Ctx *ctx, OutputStream *o, String *urn, String *mode);
@@ -618,6 +355,9 @@ void knh_ResultSet_initTargetClass(ResultSet *o, knh_class_t tcid);
 String *knh_ResultSet_getName(Ctx *ctx, ResultSet *o, size_t n);
 int knh_ResultSet_findColumn(Ctx *ctx, ResultSet *o, knh_bytes_t name);
 knh_type_t knh_ResultSet_get_type(Ctx *ctx, ResultSet *o, size_t n);
+knh_integer_t knh_ResultSet_getInt(Ctx *ctx, ResultSet *o, size_t n);
+knh_float_t knh_ResultSet_getFloat(Ctx *ctx, ResultSet *o, size_t n);
+String* knh_ResultSet_getString(Ctx *ctx, ResultSet *o, size_t n);
 /* ../src/class/knh_Runtime.c */
 knh_bytes_t knh_Runtime_aliasURN(Ctx *ctx, knh_bytes_t aurn);
 void knh_Runtime_setAliasURN(Ctx *ctx, String *alias, String *urn);
@@ -635,6 +375,9 @@ String *new_StringX(Ctx *ctx, knh_class_t cid, knh_bytes_t t, String *orign);
 String *new_String__integer(Ctx *ctx, knh_integer_t n);
 String *new_String__float(Ctx *ctx, knh_float_t n);
 char *knh_StringNULL_tochar(String *o);
+knh_bool_t knh_String_equals(String *o, knh_bytes_t s);
+knh_bool_t knh_String_startsWith(String *b, knh_bytes_t s);
+knh_bool_t knh_String_endsWith(String *b, knh_bytes_t s);
 /* ../src/class/knh_String_mbytes.c */
 knh_bool_t knh_bytes_checkENCODING(knh_bytes_t s);
 size_t knh_bytes_mlen(knh_bytes_t s);
@@ -769,17 +512,17 @@ void knh_dbcurfree__NOP(knh_dbcur_t *dbcur);
 void knh_write_USING_SQLITE3(Ctx *ctx, OutputStream *w);
 knh_db_drvapi_t *knh_System_getDefaultDBDriver();
 knh_db_drvapi_t *knh_System_getDBDriver(Ctx *ctx, knh_bytes_t name);
-void KNHINIT init_DB(Ctx *ctx);
+void  init_DB(Ctx *ctx);
 /* ../src/deps/driver_io.c */
 knh_iodrv_t *knh_System_getIODriver(Ctx *ctx, knh_bytes_t name);
 knh_iodrv_t knh_System_getDefaultIODriver();
-void KNHINIT init_IO(Ctx *ctx);
+void  init_IO(Ctx *ctx);
 InputStream *new_InputStream__stdio(Ctx *ctx, FILE *fp, String *enc);
 OutputStream *new_OutputStream__stdio(Ctx *ctx, FILE *fp, String *enc);
 /* ../src/deps/driver_regex.c */
 void knh_write_USING_REGEX(Ctx *ctx, OutputStream *w);
 knh_regex_drvapi_t *knh_System_getRegexDriver(Ctx *ctx, knh_bytes_t name);
-void KNHINIT init_Regex(Ctx *ctx);
+void  init_Regex(Ctx *ctx);
 /* ../src/deps/posix.c */
 void *knh_dlopen(Ctx *ctx, const char* path, int mode);
 void *knh_dlsym(Ctx *ctx, void* hdr, const char* symbol);
@@ -797,6 +540,11 @@ void *knh_dlsym(Ctx *ctx, void* handle, const char* symbol);
 const char *knh_dlerror(Ctx *ctx);
 int knh_dlclose(Ctx *ctx, void* handle);
 char * knh_format_homepath(char *buf, size_t bufsiz);
+/* ../src/deps/thread.c */
+int knh_thread_key_create(knh_thread_key_t *key);
+int knh_thread_setspecific(knh_thread_key_t key, const void *data);
+void* knh_thread_getspecific(knh_thread_key_t key);
+int knh_thread_key_delete(knh_thread_key_t key);
 /* ../src/deps/win32.c */
 void *knh_dlopen(Ctx *ctx, const char* path, int mode);
 void *knh_dlsym(Ctx *ctx, void* handle, const char* symbol);
@@ -809,6 +557,11 @@ knh_uinteger_t knh_initseed();
 knh_uint64_t knh_timecount();
 /* ../src/konoha.c */
 int main(int argc, char **argv);
+/* ../src/main/b4.c */
+void konoha_initfibo(Ctx *ctx);
+METHOD knh__Script_fibo(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__Script_changeChannel(Ctx *ctx, knh_sfp_t *sfp);
+METHOD knh__Script_hook(Ctx *ctx, knh_sfp_t *sfp);
 /* ../src/main/knh_tClass.c */
 void KNH_ACLASS(Ctx *ctx, knh_class_t cid, knh_class_t p1);
 void KNH_ICLASS(Ctx *ctx, knh_class_t cid, knh_class_t p1);
@@ -848,6 +601,7 @@ int knh_System_using(Ctx *ctx, knh_bytes_t name);
 NameSpace *knh_Runtime_getNameSpace(Ctx *ctx, knh_bytes_t name);
 ClassSpec *knh_System_loadClassSpec(Ctx *ctx, knh_class_t bcid, knh_bytes_t urn);
 /* ../src/main/konoha_api.c */
+void konoha_init(void);
 METHOD knh__Script_eval(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Script_isStatement(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Script_readLine(Ctx *ctx, knh_sfp_t *sfp);
@@ -871,7 +625,12 @@ char * knh_format_catpath(char *buf, size_t bufsiz, knh_bytes_t path, knh_bytes_
 /* ../src/main/konoha_locale.c */
 char *konoha_encoding();
 char *knh_format_lang(char *buf, size_t bufsiz);
-/* ../src/main/konoha_memory.c */
+/* ../src/main/konoha_pkgapi.c */
+/* ../src/main/konoha_print.c */
+void knh_stack_pmsg(Ctx *ctx, knh_sfp_t *sfp, knh_flag_t flag, String *s);
+void knh_stack_p(Ctx *ctx, knh_sfp_t *sfp, knh_flag_t flag, knh_methodn_t mn, int sfpidx);
+int knh_verbose(void);
+/* ../src/main/memory.c */
 void *knh_malloc(Ctx *ctx, size_t size);
 void knh_free(Ctx *ctx, void *block, size_t size);
 void *DBG2_malloc(Ctx *ctx, size_t size, char *func);
@@ -890,16 +649,11 @@ void knh_Object_mark0(Ctx *ctx, Object *o);
 METHOD knh__System_gc(Ctx *ctx, knh_sfp_t *sfp);
 void knh_Object_RCsweep(Ctx *ctx, Object *o);
 knh_ftraverse konoha_getDefaultSweepFunction();
-/* ../src/main/konoha_pkgapi.c */
-/* ../src/main/konoha_print.c */
-void knh_stack_pmsg(Ctx *ctx, knh_sfp_t *sfp, knh_flag_t flag, String *s);
-void knh_stack_p(Ctx *ctx, knh_sfp_t *sfp, knh_flag_t flag, knh_methodn_t mn, int sfpidx);
-int knh_verbose(void);
-/* ../src/main/konoha_stack.c */
+/* ../src/main/stack.c */
 int knh_sfp_argc(Ctx *ctx, knh_sfp_t *varg);
 char * knh_format_mtdparam(Ctx *ctx, char *buf, size_t bufsiz, Method *mtd, int n); void knh_sfp_typecheck(Ctx *ctx, knh_sfp_t *sfp, Method *mtd, knh_code_t *pc);
 void knh_sfp_dump(Ctx *ctx, knh_sfp_t *sfp);
-/* ../src/main/konoha_system.c */
+/* ../src/main/system.c */
 int knh_bytes_isOptionalMT(knh_bytes_t t);
 knh_bytes_t knh_bytes_mtoption(knh_bytes_t t);
 char *knh_format_newFMT(char *buf, size_t bufsiz, knh_bytes_t t, int dot, char *fmt);
@@ -911,11 +665,11 @@ char *knh_format_methodn(Ctx *ctx, char *buf, size_t bufsiz, knh_methodn_t mn);
 char * knh_format_cmethodn(Ctx *ctx, char *buf, size_t bufsiz, knh_class_t cid, knh_methodn_t mn);
 knh_fileid_t knh_tName_getFileId(Ctx *ctx, knh_bytes_t t);
 String *knh_tfileid_name(Ctx *ctx, knh_fileid_t fileid);
-/* ../src/main/konoha_table.c */
+/* ../src/main/systemtable.c */
 void konoha_initContext(Ctx *ctx, knh_Context_t *o, size_t stacksize);
 void knh_Context_traverse(Ctx *ctx, knh_Context_t *o, knh_ftraverse ftr);
 void konoha_traverse(Ctx* ctx, knh_ftraverse ftr);
-/* ../src/main/konoha_typesystem.c */
+/* ../src/main/typesystem.c */
 knh_bool_t knh_class_instanceof(Ctx *ctx, knh_class_t scid, knh_class_t tcid);
 METHOD knh__Object_opInstanceof(Ctx *ctx, knh_sfp_t *sfp);
 knh_bool_t knh_Object_opTypeOf(Ctx *ctx, Object *o, knh_type_t t);
