@@ -1,7 +1,7 @@
 /****************************************************************************
  * KONOHA COPYRIGHT, LICENSE NOTICE, AND DISCRIMER  
  * 
- * Copyright (c) 2005-2008, Kimio Kuramitsu <kimio at ynu.ac.jp>
+ * Copyright (c) 2005-2009, Kimio Kuramitsu <kimio at ynu.ac.jp>
  *           (c) 2008-      Konoha Software Foundation  
  * All rights reserved.
  * 
@@ -544,28 +544,28 @@ static knh_StructData_t StructData[] = {
 };
 
 static knh_ClassData_t ClassData[] = {
-	{"konoha.Object", CLASS_Object, CFLAG_Object, STRUCT_Object, CLASS_Object, 0, 33, 0, knh_Object_fdefault},
+	{"konoha.Object", CLASS_Object, CFLAG_Object, STRUCT_Object, CLASS_Object, 0, 32, 0, knh_Object_fdefault},
 	{"konoha.Any", CLASS_Any, CFLAG_Any, STRUCT_Any, CLASS_Object, 0, 0, 0, knh_Any_fdefault},
 	{"konoha.This", CLASS_This, CFLAG_This, STRUCT_This, CLASS_Any, 0, 0, 0, knh_This_fdefault},
 	{"konoha.Any0", CLASS_Any0, CFLAG_Any0, STRUCT_Any0, CLASS_Any, 0, 0, 0, knh_Any0_fdefault},
 	{"konoha.Any1", CLASS_Any1, CFLAG_Any1, STRUCT_Any1, CLASS_Any, 0, 0, 0, knh_Any1_fdefault},
 	{"konoha.Any2", CLASS_Any2, CFLAG_Any2, STRUCT_Any2, CLASS_Any, 0, 0, 0, knh_Any2_fdefault},
 	{"konoha.Any3", CLASS_Any3, CFLAG_Any3, STRUCT_Any3, CLASS_Any, 0, 0, 0, knh_Any3_fdefault},
-	{"konoha.Nue", CLASS_Nue, CFLAG_Nue, STRUCT_Nue, CLASS_Object, 0, 2, 0, knh_Nue_fdefault},
+	{"konoha.Nue", CLASS_Nue, CFLAG_Nue, STRUCT_Nue, CLASS_Object, 0, 1, 0, knh_Nue_fdefault},
 	{"konoha.Boolean", CLASS_Boolean, CFLAG_Boolean, STRUCT_Boolean, CLASS_Object, 0, 3, 0, knh_Boolean_fdefault},
 	{"konoha.Number", CLASS_Number, CFLAG_Number, STRUCT_Number, CLASS_Object, 0, 0, 0, knh_Number_fdefault},
 	{"konoha.Int", CLASS_Int, CFLAG_Int, STRUCT_Int, CLASS_Number, 0, 30, 0, knh_Int_fdefault},
 	{"konoha.IntX", CLASS_IntX, CFLAG_IntX, STRUCT_IntX, CLASS_Number, 0, 0, 0, knh_IntX_fdefault},
 	{"konoha.Float", CLASS_Float, CFLAG_Float, STRUCT_Float, CLASS_Number, 0, 20, 0, knh_Float_fdefault},
 	{"konoha.FloatX", CLASS_FloatX, CFLAG_FloatX, STRUCT_FloatX, CLASS_Number, 0, 0, 0, knh_FloatX_fdefault},
-	{"konoha.String", CLASS_String, CFLAG_String, STRUCT_String, CLASS_Object, 0, 23, 0, knh_String_fdefault},
+	{"konoha.String", CLASS_String, CFLAG_String, STRUCT_String, CLASS_Object, 0, 24, 0, knh_String_fdefault},
 	{"konoha.StringX", CLASS_StringX, CFLAG_StringX, STRUCT_StringX, CLASS_String, 0, 0, 0, knh_StringX_fdefault},
 	{"konoha.Bytes", CLASS_Bytes, CFLAG_Bytes, STRUCT_Bytes, CLASS_Object, 0, 9, 0, knh_Bytes_fdefault},
 	{"konoha.Tuple2", CLASS_Tuple2, CFLAG_Tuple2, STRUCT_Tuple2, CLASS_Object, 0, 0, 0, knh_Tuple2_fdefault},
 	{"konoha.Range", CLASS_Range, CFLAG_Range, STRUCT_Range, CLASS_Object, 0, 0, 0, knh_Range_fdefault},
-	{"konoha.Array", CLASS_Array, CFLAG_Array, STRUCT_Array, CLASS_Object, 0, 30, 0, knh_Array_fdefault},
-	{"konoha.IArray", CLASS_IArray, CFLAG_IArray, STRUCT_IArray, CLASS_Object, 0, 17, 0, knh_IArray_fdefault},
-	{"konoha.FArray", CLASS_FArray, CFLAG_FArray, STRUCT_FArray, CLASS_Object, 0, 17, 0, knh_FArray_fdefault},
+	{"konoha.Array", CLASS_Array, CFLAG_Array, STRUCT_Array, CLASS_Object, 0, 31, 0, knh_Array_fdefault},
+	{"Int[]", CLASS_IArray, CFLAG_IArray, STRUCT_IArray, CLASS_Object, 0, 18, 0, knh_IArray_fdefault},
+	{"Float[]", CLASS_FArray, CFLAG_FArray, STRUCT_FArray, CLASS_Object, 0, 18, 0, knh_FArray_fdefault},
 	{"konoha.Iterator", CLASS_Iterator, CFLAG_Iterator, STRUCT_Iterator, CLASS_Object, 0, 2, 0, knh_Iterator_fdefault},
 	{"konoha.DictMap", CLASS_DictMap, CFLAG_DictMap, STRUCT_DictMap, CLASS_Object, 0, 12, 0, knh_DictMap_fdefault},
 	{"konoha.DictSet", CLASS_DictSet, CFLAG_DictSet, STRUCT_DictSet, CLASS_Object, 0, 13, 0, knh_DictSet_fdefault},
@@ -585,13 +585,13 @@ static knh_ClassData_t ClassData[] = {
 	{"konoha.Regex", CLASS_Regex, CFLAG_Regex, STRUCT_Regex, CLASS_Object, 0, 2, 0, knh_Regex_fdefault},
 	{"konoha.BytesConv", CLASS_BytesConv, CFLAG_BytesConv, STRUCT_BytesConv, CLASS_Object, 0, 1, 0, knh_BytesConv_fdefault},
 	{"konoha.StringUnit", CLASS_StringUnit, CFLAG_StringUnit, STRUCT_StringUnit, CLASS_Object, 0, 0, 0, knh_StringUnit_fdefault},
-	{"konoha.InputStream", CLASS_InputStream, CFLAG_InputStream, STRUCT_InputStream, CLASS_Object, 0, 7, 0, knh_InputStream_fdefault},
+	{"konoha.InputStream", CLASS_InputStream, CFLAG_InputStream, STRUCT_InputStream, CLASS_Object, 0, 6, 0, knh_InputStream_fdefault},
 	{"konoha.OutputStream", CLASS_OutputStream, CFLAG_OutputStream, STRUCT_OutputStream, CLASS_Object, 0, 15, 0, knh_OutputStream_fdefault},
 	{"konoha.Connection", CLASS_Connection, CFLAG_Connection, STRUCT_Connection, CLASS_Object, 0, 4, 0, knh_Connection_fdefault},
 	{"konoha.ResultSet", CLASS_ResultSet, CFLAG_ResultSet, STRUCT_ResultSet, CLASS_Object, 0, 9, 0, knh_ResultSet_fdefault},
 	{"konoha.Exception", CLASS_Exception, CFLAG_Exception, STRUCT_Exception, CLASS_Object, 0, 9, 0, knh_Exception_fdefault},
 	{"konoha.ExceptionHandler", CLASS_ExceptionHandler, CFLAG_ExceptionHandler, STRUCT_ExceptionHandler, CLASS_Object, 0, 0, 0, knh_ExceptionHandler_fdefault},
-	{"konoha.Script", CLASS_Script, CFLAG_Script, STRUCT_Script, CLASS_Object, 0, 6, 0, knh_Script_fdefault},
+	{"konoha.Script", CLASS_Script, CFLAG_Script, STRUCT_Script, CLASS_Object, 0, 9, 0, knh_Script_fdefault},
 	{"konoha.NameSpace", CLASS_NameSpace, CFLAG_NameSpace, STRUCT_NameSpace, CLASS_Object, 0, 0, 0, knh_NameSpace_fdefault},
 	{"konoha.System", CLASS_System, CFLAG_System, STRUCT_System, CLASS_Object, 0, 15, 0, knh_System_fdefault},
 	{"konoha.Context", CLASS_Context, CFLAG_Context, STRUCT_Context, CLASS_Object, 0, 16, 0, knh_Context_fdefault},
@@ -610,6 +610,11 @@ static knh_GenericsData_t GenericsData[] = {
 	{NULL}
 };
 
+static knh_ClosureData_t ClosureData[] = {
+	{"int(Any1!,Any1!)", CLASS_ArrayCmp, NNTYPE_Int, NNTYPE_Any1, NNTYPE_Any1, TYPE_void},
+	{NULL}
+};
+
 static knh_ExptData_t ExptData[] = {
 	{"Exception", 0, EXPT_Exception, NULL},
 	{"Fatal", 0, EXPT_Fatal, NULL},
@@ -663,10 +668,11 @@ static knh_FieldNameData_t FieldNameData[] = {
 	{"buf", FIELDN_buf},
 	{"c", FIELDN_c},
 	{"callcc", FIELDN_callcc},
+	{"ch", FIELDN_ch},
+	{"changeChannel", FIELDN_changeChannel},
 	{"class", FIELDN_class},
 	{"clear", FIELDN_clear},
 	{"close", FIELDN_close},
-	{"compareTo", FIELDN_compareTo},
 	{"concat", FIELDN_concat},
 	{"const", FIELDN_const},
 	{"copy", FIELDN_copy},
@@ -683,17 +689,20 @@ static knh_FieldNameData_t FieldNameData[] = {
 	{"encoding", FIELDN_encoding},
 	{"endsWith", FIELDN_endsWith},
 	{"equals", FIELDN_equals},
+	{"equalsIgnoreCase", FIELDN_equalsIgnoreCase},
 	{"err", FIELDN_err},
 	{"eval", FIELDN_eval},
 	{"exec", FIELDN_exec},
 	{"exit", FIELDN_exit},
 	{"f", FIELDN_f},
+	{"fibo", FIELDN_fibo},
 	{"file", FIELDN_file},
 	{"float", FIELDN_float},
 	{"flush", FIELDN_flush},
 	{"format", FIELDN_format},
 	{"formatted", FIELDN_formatted},
 	{"func", FIELDN_func},
+	{"funcname", FIELDN_funcname},
 	{"g", FIELDN_g},
 	{"gCMarked", FIELDN_gCMarked},
 	{"gc", FIELDN_gc},
@@ -702,6 +711,7 @@ static knh_FieldNameData_t FieldNameData[] = {
 	{"hasFile", FIELDN_hasFile},
 	{"hasLibrary", FIELDN_hasLibrary},
 	{"hasMetaData", FIELDN_hasMetaData},
+	{"hook", FIELDN_hook},
 	{"i", FIELDN_i},
 	{"in", FIELDN_in},
 	{"index", FIELDN_index},
@@ -898,6 +908,7 @@ static knh_MethodFieldData_t MethodFieldData[] = {
 	{MFN_void, 0+ 0, TYPE_void},
 	{MFN_nInt_Any1, 1+ 0, NNTYPE_Int, TYPE_Any1, FIELDN_v},
 	{MFN_nBoolean_Any1, 1+ 0, NNTYPE_Boolean, TYPE_Any1, FIELDN_v},
+	{MFN_void_ArrayCmp, 1+ 0, TYPE_void, TYPE_ArrayCmp, FIELDN_f},
 	{MFN_iAny1, 0+ 0, NNITYPE_Any1},
 	{MFN_nThis_nInt_nInt, 2+ 0, NNTYPE_This, NNTYPE_Int, FIELDN_x, NNTYPE_Int, FIELDN_y},
 	{MFN_nThis_nInt_nInt_nInt, 3+ 0, NNTYPE_This, NNTYPE_Int, FIELDN_x, NNTYPE_Int, FIELDN_y, NNTYPE_Int, FIELDN_z},
@@ -915,26 +926,25 @@ static knh_MethodFieldData_t MethodFieldData[] = {
 	{MFN_void_nInt_nInt_nInt_nFloat, 4+ 0, TYPE_void, NNTYPE_Int, FIELDN_x, NNTYPE_Int, FIELDN_y, NNTYPE_Int, FIELDN_z, NNTYPE_Float, FIELDN_v},
 	{MFN_nBytes_Int, 1+ 0, NNTYPE_Bytes, TYPE_Int, FIELDN_i},
 	{MFN_void_nBytes_Int_Int, 3+ 0, TYPE_void, NNTYPE_Bytes, FIELDN_b, TYPE_Int, FIELDN_n, TYPE_Int, FIELDN_l},
-	{MFN_nThis_Any1_, 1+ 0, NNTYPE_This, TYPE_Any1, FIELDN_v},
-	{MFN_Any1_nString, 1+ 0, TYPE_Any1, NNTYPE_String, FIELDN_k},
-	{MFN_nBoolean_nString, 1+ 0, NNTYPE_Boolean, NNTYPE_String, FIELDN_k},
-	{MFN_void_nString_Any1, 2+ 0, TYPE_void, NNTYPE_String, FIELDN_k, TYPE_Any1, FIELDN_v},
-	{MFN_void_nString, 1+ 0, TYPE_void, NNTYPE_String, FIELDN_k},
-	{MFN_void_Any_, 1+ 0, TYPE_void, TYPE_Any, FIELDN_v},
-	{MFN_iString, 0+ 0, NNITYPE_String},
-	{MFN_nInt_nString, 1+ 0, NNTYPE_Int, NNTYPE_String, FIELDN_k},
-	{MFN_void_nString_nInt, 2+ 0, TYPE_void, NNTYPE_String, FIELDN_k, NNTYPE_Int, FIELDN_v},
-	{MFN_void_String_, 1+ 0, TYPE_void, TYPE_String, FIELDN_v},
-	{MFN_nException_String_Any, 2+ 0, NNTYPE_Exception, TYPE_String, FIELDN_m, TYPE_Any, FIELDN_b},
-	{MFN_void_nAny1_Any2, 2+ 0, TYPE_void, NNTYPE_Any1, FIELDN_k, TYPE_Any2, FIELDN_v},
 	{MFN_nConnection_nString, 1+ 0, NNTYPE_Connection, NNTYPE_String, FIELDN_u},
 	{MFN_nResultSet_nString, 1+ 0, NNTYPE_ResultSet, NNTYPE_String, FIELDN_q},
+	{MFN_void_nString, 1+ 0, TYPE_void, NNTYPE_String, FIELDN_q},
 	{MFN_nInt_nAny, 1+ 0, NNTYPE_Int, NNTYPE_Any, FIELDN_n},
 	{MFN_nString_nInt, 1+ 0, NNTYPE_String, NNTYPE_Int, FIELDN_n},
 	{MFN_Int_nAny, 1+ 0, TYPE_Int, NNTYPE_Any, FIELDN_n},
 	{MFN_Float_nAny, 1+ 0, TYPE_Float, NNTYPE_Any, FIELDN_n},
 	{MFN_String_nAny, 1+ 0, TYPE_String, NNTYPE_Any, FIELDN_n},
 	{MFN_Any_nAny, 1+ 0, TYPE_Any, NNTYPE_Any, FIELDN_n},
+	{MFN_nThis_Any1_, 1+ 0, NNTYPE_This, TYPE_Any1, FIELDN_v},
+	{MFN_Any1_nString, 1+ 0, TYPE_Any1, NNTYPE_String, FIELDN_k},
+	{MFN_nBoolean_nString, 1+ 0, NNTYPE_Boolean, NNTYPE_String, FIELDN_k},
+	{MFN_void_nString_Any1, 2+ 0, TYPE_void, NNTYPE_String, FIELDN_k, TYPE_Any1, FIELDN_v},
+	{MFN_void_Any_, 1+ 0, TYPE_void, TYPE_Any, FIELDN_v},
+	{MFN_iString, 0+ 0, NNITYPE_String},
+	{MFN_nInt_nString, 1+ 0, NNTYPE_Int, NNTYPE_String, FIELDN_k},
+	{MFN_void_nString_nInt, 2+ 0, TYPE_void, NNTYPE_String, FIELDN_k, NNTYPE_Int, FIELDN_v},
+	{MFN_void_String_, 1+ 0, TYPE_void, TYPE_String, FIELDN_v},
+	{MFN_void_nAny1_Any2, 2+ 0, TYPE_void, NNTYPE_Any1, FIELDN_k, TYPE_Any2, FIELDN_v},
 	{MFN_nBoolean, 0+ 0, NNTYPE_Boolean},
 	{MFN_nBoolean_nInt, 1+ 0, NNTYPE_Boolean, NNTYPE_Int, FIELDN_v},
 	{MFN_nInt_nInt_, 1+ 0, NNTYPE_Int, NNTYPE_Int, FIELDN_v},
@@ -944,15 +954,14 @@ static knh_MethodFieldData_t MethodFieldData[] = {
 	{MFN_nBoolean_Float, 1+ 0, NNTYPE_Boolean, TYPE_Float, FIELDN_v},
 	{MFN_nBoolean_nFloat, 1+ 0, NNTYPE_Boolean, NNTYPE_Float, FIELDN_v},
 	{MFN_nThis_Any_, 1+ 0, NNTYPE_This, TYPE_Any, FIELDN_v},
-	{MFN_nInt_Any, 1+ 0, NNTYPE_Int, TYPE_Any, FIELDN_o},
 	{MFN_nBoolean_Any, 1+ 0, NNTYPE_Boolean, TYPE_Any, FIELDN_v},
 	{MFN_nBoolean_nClass, 1+ 0, NNTYPE_Boolean, NNTYPE_Class, FIELDN_c},
 	{MFN_nClass, 0+ 0, NNTYPE_Class},
 	{MFN_iThis, 0+ 0, NNITYPE_This},
 	{MFN_InputStream_nString, 1+ 0, TYPE_InputStream, NNTYPE_String, FIELDN_u},
-	{MFN_void_String, 1+ 0, TYPE_void, TYPE_String, FIELDN_e},
 	{MFN_OutputStream_nString_String, 2+ 0, TYPE_OutputStream, NNTYPE_String, FIELDN_u, TYPE_String, FIELDN_m},
 	{MFN_void_Any, 1+ 0, TYPE_void, TYPE_Any, FIELDN_v},
+	{MFN_void_String, 1+ 0, TYPE_void, TYPE_String, FIELDN_e},
 	{MFN_nString_Any, 1+ 0, NNTYPE_String, TYPE_Any, FIELDN_v},
 	{MFN_nString_Any_, 1+ 0, NNTYPE_String, TYPE_Any, FIELDN_v},
 	{MFN_nString_nString, 1+ 0, NNTYPE_String, NNTYPE_String, FIELDN_t},
@@ -969,6 +978,7 @@ static knh_MethodFieldData_t MethodFieldData[] = {
 	{MFN_Any_nString, 1+ 0, TYPE_Any, NNTYPE_String, FIELDN_k},
 	{MFN_void_nString_Any, 2+ 0, TYPE_void, NNTYPE_String, FIELDN_k, TYPE_Any, FIELDN_v},
 	{MFN_naString_String, 1+ 0, NNATYPE_String, TYPE_String, FIELDN_k},
+	{MFN_nException_String_Any, 2+ 0, NNTYPE_Exception, TYPE_String, FIELDN_m, TYPE_Any, FIELDN_b},
 	{MFN_nThis_nAny_nMethod, 2+ 0, NNTYPE_This, NNTYPE_Any, FIELDN_b, NNTYPE_Method, FIELDN_m},
 	{MFN_Any0_Any1_Any2_Any3, 3+ 0, TYPE_Any0, TYPE_Any1, FIELDN_x, TYPE_Any2, FIELDN_y, TYPE_Any3, FIELDN_z},
 	{MFN_nException_String_String_Object, 3+ 0, NNTYPE_Exception, TYPE_String, FIELDN_e, TYPE_String, FIELDN_m, TYPE_Object, FIELDN_b},
@@ -1000,6 +1010,8 @@ static knh_MethodData_t MethodData[] = {
 	{knh__FArray_add, 0, CLASS_FArray, METHODN_add, 0, MFN_void_nFloat, (void*)NULL},
 	{knh__FArray_opLshift, KNH_FLAG_MF_VARARGS, CLASS_FArray, METHODN_opLshift, 0, MFN_void_nFloat_, (void*)NULL},
 	{knh__Array_opSize, 0, CLASS_Array, METHODN_opSize, 0, MFN_nInt, (void*)NULL},
+	{knh__Array_opSize, 0, CLASS_IArray, METHODN_opSize, 0, MFN_nInt, (void*)NULL},
+	{knh__Array_opSize, 0, CLASS_FArray, METHODN_opSize, 0, MFN_nInt, (void*)NULL},
 	{knh__Array_get, 0, CLASS_Array, METHODN_get, 0, MFN_nAny1_nInt, (void*)NULL},
 	{knh__IArray_get, 0, CLASS_IArray, METHODN_get, 0, MFN_nInt_nInt, (void*)NULL},
 	{knh__FArray_get, 0, CLASS_FArray, METHODN_get, 0, MFN_nFloat_nInt, (void*)NULL},
@@ -1017,6 +1029,7 @@ static knh_MethodData_t MethodData[] = {
 	{knh__Array_indexOf, 0, CLASS_Array, METHODN_indexOf, 0, MFN_nInt_Any1, (void*)NULL},
 	{knh__Array_lastIndexOf, 0, CLASS_Array, METHODN_lastIndexOf, 0, MFN_nInt_Any1, (void*)NULL},
 	{knh__Array_opHas, 0, CLASS_Array, METHODN_opHas, 0, MFN_nBoolean_Any1, (void*)NULL},
+	{knh__Array_sort, 0, CLASS_Array, METHODN_sort, 0, MFN_void_ArrayCmp, (void*)NULL},
 	{knh__Array_reverse, 0, CLASS_Array, METHODN_reverse, 0, MFN_void, (void*)NULL},
 	{knh__Array_swap, 0, CLASS_Array, METHODN_swap, 0, MFN_void_nInt_nInt, (void*)NULL},
 	{knh__Array_shuffle, 0, CLASS_Array, METHODN_shuffle, 0, MFN_void, (void*)NULL},
@@ -1048,6 +1061,8 @@ static knh_MethodData_t MethodData[] = {
 	{knh__FArray_get3D, 0, CLASS_FArray, METHODN_get3D, 0, MFN_nFloat_nInt_nInt_nInt, (void*)NULL},
 	{knh__FArray_set2D, 0, CLASS_FArray, METHODN_set2D, 0, MFN_void_nInt_nInt_nFloat, (void*)NULL},
 	{knh__FArray_set3D, 0, CLASS_FArray, METHODN_set3D, 0, MFN_void_nInt_nInt_nInt_nFloat, (void*)NULL},
+	{knh_fmethod_movableText, 0, CLASS_Iterator, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_Iterator__k},
+	{knh_fmethod_movableText, 0, CLASS_Iterator, METHODN__dump, 0, MFN_void_OutputStream_Any, (void*)knh_Iterator__dump},
 	{knh__Bytes_new, 0, CLASS_Bytes, METHODN_new, 0, MFN_nBytes_Int, (void*)NULL},
 	{knh__Bytes_putc, 0, CLASS_Bytes, METHODN_putc, 0, MFN_void_nInt, (void*)NULL},
 	{knh__Bytes_write, 0, CLASS_Bytes, METHODN_write, 0, MFN_void_nBytes_Int_Int, (void*)NULL},
@@ -1057,6 +1072,16 @@ static knh_MethodData_t MethodData[] = {
 	{knh__Bytes_set, 0, CLASS_Bytes, METHODN_set, 0, MFN_void_nInt_nInt, (void*)NULL},
 	{knh__Bytes_opFill, 0, CLASS_Bytes, METHODN_opFill, 0, MFN_void_nInt, (void*)NULL},
 	{knh_fmethod_movableText, 0, CLASS_Bytes, METHODN__dump, 0, MFN_void_OutputStream_Any, (void*)knh_Bytes__dump},
+	{knh__Connection_new, 0, CLASS_Connection, METHODN_new, 0, MFN_nConnection_nString, (void*)NULL},
+	{knh__Connection_query, 0, CLASS_Connection, METHODN_query, 0, MFN_nResultSet_nString, (void*)NULL},
+	{knh__Connection_exec, 0, CLASS_Connection, METHODN_exec, 0, MFN_void_nString, (void*)NULL},
+	{knh__ResultSet_opSize, 0, CLASS_ResultSet, METHODN_opSize, 0, MFN_nInt_nAny, (void*)NULL},
+	{knh__ResultSet_getName, 0, CLASS_ResultSet, METHODN_getName, 0, MFN_nString_nInt, (void*)NULL},
+	{knh__ResultSet_getInt, 0, CLASS_ResultSet, METHODN_getInt, 0, MFN_Int_nAny, (void*)NULL},
+	{knh__ResultSet_getFloat, 0, CLASS_ResultSet, METHODN_getFloat, 0, MFN_Float_nAny, (void*)NULL},
+	{knh__ResultSet_getString, 0, CLASS_ResultSet, METHODN_getString, 0, MFN_String_nAny, (void*)NULL},
+	{knh__ResultSet_get, 0, CLASS_ResultSet, METHODN_get, 0, MFN_Any_nAny, (void*)NULL},
+	{knh_fmethod_movableText, 0, CLASS_ResultSet, METHODN__dump, 0, MFN_void_OutputStream_Any, (void*)knh_ResultSet__dump},
 	{knh__DictMap_new, 0, CLASS_DictMap, METHODN_new, 0, MFN_nThis_Int, (void*)NULL},
 	{knh__DictMap_new__init, KNH_FLAG_MF_VARARGS, CLASS_DictMap, METHODN_new__init, 0, MFN_nThis_Any1_, (void*)NULL},
 	{knh__DictMap_get, 0, CLASS_DictMap, METHODN_get, 0, MFN_Any1_nString, (void*)NULL},
@@ -1080,11 +1105,6 @@ static knh_MethodData_t MethodData[] = {
 	{knh__DictSet_opItr, 0, CLASS_DictSet, METHODN_opItr, 0, MFN_iString, (void*)NULL},
 	{knh_fmethod_movableText, 0, CLASS_DictSet, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_DictSet__k},
 	{knh_fmethod_movableText, 0, CLASS_DictSet, METHODN__dump, 0, MFN_void_OutputStream_Any, (void*)knh_DictSet__dump},
-	{knh__Exception_new, 0, CLASS_Exception, METHODN_new, 0, MFN_nException_String_Any, (void*)NULL},
-	{knh__Exception_opIsa, 0, CLASS_Exception, METHODN_opIsa, 0, MFN_nBoolean_nString, (void*)NULL},
-	{knh_fmethod_movableText, 0, CLASS_Exception, METHODN__s, 0, MFN_void_OutputStream_Any, (void*)knh_Exception__s},
-	{knh_fmethod_movableText, 0, CLASS_Exception, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_Exception__k},
-	{knh_fmethod_movableText, 0, CLASS_Exception, METHODN__dump, 0, MFN_void_OutputStream_Any, (void*)knh_Exception__dump},
 	{knh__HashMap_new, 0, CLASS_HashMap, METHODN_new, 0, MFN_nThis_Int, (void*)NULL},
 	{knh__HashMap_get, 0, CLASS_HashMap, METHODN_get, 0, MFN_void_Any1, (void*)NULL},
 	{knh__HashMap_opHas, 0, CLASS_HashMap, METHODN_opHas, 0, MFN_nBoolean_Any1, (void*)NULL},
@@ -1093,18 +1113,6 @@ static knh_MethodData_t MethodData[] = {
 	{knh_fmethod_movableText, 0, CLASS_HashMap, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_HashMap__k},
 	{knh_fmethod_movableText, 0, CLASS_HashMap, METHODN__dump, 0, MFN_void_OutputStream_Any, (void*)knh_HashMap__dump},
 	{knh__HashMap_opItr, 0, CLASS_HashMap, METHODN_opItr, 0, MFN_iAny1, (void*)NULL},
-	{knh_fmethod_movableText, 0, CLASS_Iterator, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_Iterator__k},
-	{knh_fmethod_movableText, 0, CLASS_Iterator, METHODN__dump, 0, MFN_void_OutputStream_Any, (void*)knh_Iterator__dump},
-	{knh__Connection_new, 0, CLASS_Connection, METHODN_new, 0, MFN_nConnection_nString, (void*)NULL},
-	{knh__Connection_query, 0, CLASS_Connection, METHODN_query, 0, MFN_nResultSet_nString, (void*)NULL},
-	{knh__Connection_exec, 0, CLASS_Connection, METHODN_exec, 0, MFN_void_nString, (void*)NULL},
-	{knh__ResultSet_opSize, 0, CLASS_ResultSet, METHODN_opSize, 0, MFN_nInt_nAny, (void*)NULL},
-	{knh__ResultSet_getName, 0, CLASS_ResultSet, METHODN_getName, 0, MFN_nString_nInt, (void*)NULL},
-	{knh__ResultSet_getInt, 0, CLASS_ResultSet, METHODN_getInt, 0, MFN_Int_nAny, (void*)NULL},
-	{knh__ResultSet_getFloat, 0, CLASS_ResultSet, METHODN_getFloat, 0, MFN_Float_nAny, (void*)NULL},
-	{knh__ResultSet_getString, 0, CLASS_ResultSet, METHODN_getString, 0, MFN_String_nAny, (void*)NULL},
-	{knh__ResultSet_get, 0, CLASS_ResultSet, METHODN_get, 0, MFN_Any_nAny, (void*)NULL},
-	{knh_fmethod_movableText, 0, CLASS_ResultSet, METHODN__dump, 0, MFN_void_OutputStream_Any, (void*)knh_ResultSet__dump},
 	{knh__Boolean_opNot, KNH_FLAG_MF_CONST, CLASS_Boolean, METHODN_opNot, 0, MFN_nBoolean, (void*)NULL},
 	{knh__Int_opAdd, KNH_FLAG_MF_CONST, CLASS_Int, METHODN_opAdd, 0, MFN_nInt_nInt, (void*)NULL},
 	{knh__Int_opNeg, KNH_FLAG_MF_CONST, CLASS_Int, METHODN_opNeg, 0, MFN_nInt, (void*)NULL},
@@ -1158,7 +1166,6 @@ static knh_MethodData_t MethodData[] = {
 	{knh__Float__bits, 0, CLASS_Float, METHODN__bits, 0, MFN_void_OutputStream_Any, (void*)NULL},
 	{knh__Float__k, 0, CLASS_Float, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)NULL},
 	{knh__Object_new__init, KNH_FLAG_MF_VARARGS, CLASS_Object, METHODN_new__init, 0, MFN_nThis_Any_, (void*)NULL},
-	{knh__Object_compareTo, 0, CLASS_Object, METHODN_compareTo, 0, MFN_nInt_Any, (void*)NULL},
 	{knh__Object_opEq, KNH_FLAG_MF_CONST|KNH_FLAG_MF_NULLBASE, CLASS_Object, METHODN_opEq, 0, MFN_nBoolean_Any, (void*)NULL},
 	{knh__Object_opNeq, KNH_FLAG_MF_CONST|KNH_FLAG_MF_NULLBASE, CLASS_Object, METHODN_opNeq, 0, MFN_nBoolean_Any, (void*)NULL},
 	{knh__Object_opLt, KNH_FLAG_MF_CONST|KNH_FLAG_MF_NULLBASE, CLASS_Object, METHODN_opLt, 0, MFN_nBoolean_Any, (void*)NULL},
@@ -1177,7 +1184,6 @@ static knh_MethodData_t MethodData[] = {
 	{knh_fmethod_movableText, 0, CLASS_Object, METHODN__dump, 0, MFN_void_OutputStream_Any, (void*)knh_Object__dump},
 	{knh_fmethod_movableText, 0, CLASS_Object, METHODN__empty, 0, MFN_void_OutputStream_Any, (void*)knh_Object__empty},
 	{knh_fmethod_movableText, 0, CLASS_Object, METHODN__addr, 0, MFN_void_OutputStream_Any, (void*)knh_Object__addr},
-	{knh_fmethod_movableText, 0, CLASS_Nue, METHODN__s, 0, MFN_void_OutputStream_Any, (void*)knh_Nue__s},
 	{knh_fmethod_movableText, 0, CLASS_Nue, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_Nue__k},
 	{knh_fmethod_movableText, 0, CLASS_Class, METHODN__s, 0, MFN_void_OutputStream_Any, (void*)knh_Class__s},
 	{knh_fmethod_movableText, 0, CLASS_Class, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_Class__k},
@@ -1187,21 +1193,21 @@ static knh_MethodData_t MethodData[] = {
 	{knh_fmethod_movableText, 0, CLASS_Method, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_Method__k},
 	{knh_fmethod_movableText, 0, CLASS_Method, METHODN__dump, 0, MFN_void_OutputStream_Any, (void*)knh_Method__dump},
 	{knh__InputStream_new, 0, CLASS_InputStream, METHODN_new, 0, MFN_InputStream_nString, (void*)NULL},
-	{knh__InputStream_setEncoding, 0, CLASS_InputStream, METHODN_setEncoding, 0, MFN_void_String, (void*)NULL},
 	{knh__InputStream_isClosed, 0, CLASS_InputStream, METHODN_isClosed, 0, MFN_nBoolean, (void*)NULL},
-	{knh_fmethod_movableText, 0, CLASS_InputStream, METHODN__dump, 0, MFN_void_OutputStream_Any, (void*)knh_InputStream__dump},
 	{knh_fmethod_movableText, 0, CLASS_InputStream, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_InputStream__k},
 	{knh__OutputStream_new, 0, CLASS_OutputStream, METHODN_new, 0, MFN_OutputStream_nString_String, (void*)NULL},
 	{knh__OutputStream_write, 0, CLASS_OutputStream, METHODN_write, 0, MFN_void_nBytes_Int_Int, (void*)NULL},
 	{knh__OutputStream_isClosed, 0, CLASS_OutputStream, METHODN_isClosed, 0, MFN_nBoolean, (void*)NULL},
-	{knh__OutputStream_setEncoding, 0, CLASS_OutputStream, METHODN_setEncoding, 0, MFN_void_String, (void*)NULL},
 	{knh__OutputStream_print, 0, CLASS_OutputStream, METHODN_print, 0, MFN_void_Any, (void*)NULL},
 	{knh__OutputStream_println, 0, CLASS_OutputStream, METHODN_println, 0, MFN_void_Any, (void*)NULL},
 	{knh__OutputStream_opLshift, KNH_FLAG_MF_VARARGS, CLASS_OutputStream, METHODN_opLshift, 0, MFN_void_Any_, (void*)NULL},
 	{knh_fmethod_movableText, 0, CLASS_OutputStream, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_OutputStream__k},
-	{knh__String_equals, 0, CLASS_String, METHODN_equals, 0, MFN_nBoolean_nString, (void*)NULL},
-	{knh__String_startsWith, 0, CLASS_String, METHODN_startsWith, 0, MFN_nBoolean_nString, (void*)NULL},
-	{knh__String_endsWith, 0, CLASS_String, METHODN_endsWith, 0, MFN_nBoolean_nString, (void*)NULL},
+	{knh__InputStream_setEncoding, 0, CLASS_InputStream, METHODN_setEncoding, 0, MFN_void_String, (void*)NULL},
+	{knh__OutputStream_setEncoding, 0, CLASS_OutputStream, METHODN_setEncoding, 0, MFN_void_String, (void*)NULL},
+	{knh__String_equals, KNH_FLAG_MF_CONST, CLASS_String, METHODN_equals, 0, MFN_nBoolean_nString, (void*)NULL},
+	{knh__String_equalsIgnoreCase, KNH_FLAG_MF_CONST, CLASS_String, METHODN_equalsIgnoreCase, 0, MFN_nBoolean_nString, (void*)NULL},
+	{knh__String_startsWith, KNH_FLAG_MF_CONST, CLASS_String, METHODN_startsWith, 0, MFN_nBoolean_nString, (void*)NULL},
+	{knh__String_endsWith, KNH_FLAG_MF_CONST, CLASS_String, METHODN_endsWith, 0, MFN_nBoolean_nString, (void*)NULL},
 	{knh__String_indexOf, KNH_FLAG_MF_CONST, CLASS_String, METHODN_indexOf, 0, MFN_nInt_nString, (void*)NULL},
 	{knh__String_opSize, KNH_FLAG_MF_CONST|KNH_FLAG_MF_NULLBASE, CLASS_String, METHODN_opSize, 0, MFN_nInt, (void*)NULL},
 	{knh__String_opAdd, KNH_FLAG_MF_CONST|KNH_FLAG_MF_NULLBASE, CLASS_String, METHODN_opAdd, 0, MFN_nString_Any, (void*)NULL},
@@ -1230,16 +1236,21 @@ static knh_MethodData_t MethodData[] = {
 	{knh__System_exit, KNH_FLAG_MF_STATIC, CLASS_System, METHODN_exit, 0, MFN_void_Int, (void*)NULL},
 	{knh__System_hasDir, 0, CLASS_System, METHODN_hasDir, 0, MFN_nBoolean_nString, (void*)NULL},
 	{knh__System_hasFile, 0, CLASS_System, METHODN_hasFile, 0, MFN_nBoolean_nString, (void*)NULL},
-	{knh_fmethod_movableText, 0, CLASS_System, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_System__k},
-	{knh_fmethod_movableText, 0, CLASS_System, METHODN__dump, 0, MFN_void_OutputStream_Any, (void*)knh_System__dump},
 	{knh__Context_getProperty, 0, CLASS_Context, METHODN_getProperty, 0, MFN_Any_nString, (void*)NULL},
 	{knh__Context_setProperty, 0, CLASS_Context, METHODN_setProperty, 0, MFN_void_nString_Any, (void*)NULL},
 	{knh__Context_listProperties, 0, CLASS_Context, METHODN_listProperties, 0, MFN_naString_String, (void*)NULL},
-	{knh__Context_setEncoding, 0, CLASS_Context, METHODN_setEncoding, 0, MFN_void_String, (void*)NULL},
 	{knh__Context_setIn, 0, CLASS_Context, METHODN_setIn, 0, MFN_void_InputStream, (void*)NULL},
 	{knh__Context_setOut, 0, CLASS_Context, METHODN_setOut, 0, MFN_void_OutputStream, (void*)NULL},
 	{knh__Context_setErr, 0, CLASS_Context, METHODN_setErr, 0, MFN_void_OutputStream, (void*)NULL},
 	{knh_fmethod_movableText, 0, CLASS_Context, METHODN__dump, 0, MFN_void_OutputStream_Any, (void*)knh_Context__dump},
+	{knh__Exception_new, 0, CLASS_Exception, METHODN_new, 0, MFN_nException_String_Any, (void*)NULL},
+	{knh__Exception_opIsa, 0, CLASS_Exception, METHODN_opIsa, 0, MFN_nBoolean_nString, (void*)NULL},
+	{knh_fmethod_movableText, 0, CLASS_Exception, METHODN__s, 0, MFN_void_OutputStream_Any, (void*)knh_Exception__s},
+	{knh_fmethod_movableText, 0, CLASS_Exception, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_Exception__k},
+	{knh_fmethod_movableText, 0, CLASS_Exception, METHODN__dump, 0, MFN_void_OutputStream_Any, (void*)knh_Exception__dump},
+	{knh_fmethod_movableText, 0, CLASS_System, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_System__k},
+	{knh_fmethod_movableText, 0, CLASS_System, METHODN__dump, 0, MFN_void_OutputStream_Any, (void*)knh_System__dump},
+	{knh__Context_setEncoding, 0, CLASS_Context, METHODN_setEncoding, 0, MFN_void_String, (void*)NULL},
 	{knh_fmethod_movableText, 0, CLASS_BytesConv, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_BytesConv__k},
 	{knh_fmethod_movableText, 0, CLASS_ClassMap, METHODN__dump, 0, MFN_void_OutputStream_Any, (void*)knh_ClassMap__dump},
 	{knh__Closure_new, 0, CLASS_Closure, METHODN_new, 0, MFN_nThis_nAny_nMethod, (void*)NULL},
@@ -1280,6 +1291,9 @@ static knh_MethodData_t MethodData[] = {
 	{knh_fmethod_movableText, 0, CLASS_Token, METHODN__s, 0, MFN_void_OutputStream_Any, (void*)knh_Token__s},
 	{knh_fmethod_movableText, 0, CLASS_Token, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_Token__k},
 	{knh_fmethod_movableText, 0, CLASS_Token, METHODN__dump, 0, MFN_void_OutputStream_Any, (void*)knh_Token__dump},
+	{knh__Script_fibo, 0, CLASS_Script, METHODN_fibo, 0, MFN_nInt_nInt, (void*)NULL},
+	{knh__Script_changeChannel, 0, CLASS_Script, METHODN_changeChannel, 0, MFN_void_nInt, (void*)NULL},
+	{knh__Script_hook, 0, CLASS_Script, METHODN_hook, 0, MFN_void_nString, (void*)NULL},
 	{knh__System_hasLibrary, KNH_FLAG_MF_STATIC, CLASS_System, METHODN_hasLibrary, 0, MFN_nBoolean_nString_String, (void*)NULL},
 	{knh__Script_eval, 0, CLASS_Script, METHODN_eval, 0, MFN_void_String_String_Int, (void*)NULL},
 	{knh__Script_isStatement, 0, CLASS_Script, METHODN_isStatement, 0, MFN_nBoolean_nString, (void*)NULL},
