@@ -464,11 +464,23 @@ typedef struct knh_sfp_t {
 		return; \
 	}\
 
+#define KNH_RETURN_NNInt(ctx, sfp, n)      {\
+		KNH_NGCMOV(ctx, sfp[-1].o, KNH_INT0);\
+		sfp[-1].ivalue = (knh_integer_t)n;\
+		return; \
+	}\
+
 #define KNH_RETURN_Float(ctx, sfp, n)      {\
 		sfp[-1].fvalue = (knh_float_t)n;\
 		return; \
 	}\
 
+#define KNH_RETURN_NNFloat(ctx, sfp, n)      {\
+		KNH_NGCMOV(ctx, sfp[-1].o, KNH_FLOAT0);\
+		sfp[-1].fvalue = (knh_float_t)n;\
+		return; \
+	}\
+
 #define KNH_ITRNEXT(ctx, sfp, i, v) {\
 		KNH_MOV(ctx, sfp[i].o, v);\
 		sfp[i].data = ((Int*)v)->n.data;\
@@ -533,6 +545,20 @@ typedef const struct knh_Context_t    Ctx;
 
 #define KNH_SMALLMALLOC_SIZE 80
 
+/* ------------------------------------------------------------------------ */
+/* [Thread] */
+/* ------------------------------------------------------------------------ */
+
+#define KNH_USING_NOTHREAD 1
+#ifdef KNH_USING_PTHREAD
+#undef KNH_USING_NOTHREAD
+#define knh_thread_key_t pthread_key_t
+#endif
+
+#ifdef KNH_USING_NOTHREAD
+#define knh_thread_key_t int
+#endif
+
 /* ------------------------------------------------------------------------ */
 
 #define STRUCT_newid         ((knh_struct_t)-1)
