@@ -35,15 +35,14 @@
 extern "C" {
 #endif
 
-/* ======================================================================== */
-/* [constructor] */
+#ifdef KNH_CC_METHODAPI
 
 void knh_KLRCode__dumpmtd(Ctx *ctx, KLRCode* o, OutputStream *w, Method *mtd);
 
 /* ------------------------------------------------------------------------ */
 /* @method[VARARGS] This! Object.new:init(Any value) @VARARGS */
 
-METHOD knh__Object_new__init(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Object_new__init(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Object *o = sfp[0].o;
 //	knh_class_t cid = knh_Object_cid(o);
@@ -67,59 +66,9 @@ METHOD knh__Object_new__init(Ctx *ctx, knh_sfp_t *sfp)
 }
 
 /* ======================================================================== */
-/* [method] */
-
-/* ------------------------------------------------------------------------ */
-/* @method Int! Object.compareTo(Any o) */
-
-INLINE
-int knh_Object_compareTo(Ctx *ctx, Object *o1, Object *o2)
-{
-	knh_class_t bcid = o1->h.bcid;
-	knh_class_t bcid2 = o2->h.bcid;
-	if(bcid == bcid2) {
-		if(bcid == CLASS_Object) {
-			int idx = ctx->tClass[o1->h.cid].keyidx;
-			if(idx != -1) {
-				int res = knh_Object_compareTo(ctx, KNH_FIELDn(o1, idx), KNH_FIELDn(o2, idx));
-				if(res == 0) return res;
-				idx = ctx->tClass[o1->h.cid].keyidx2;
-				if(idx != -1) {
-					return knh_Object_compareTo(ctx, KNH_FIELDn(o1, idx), KNH_FIELDn(o2, idx));
-				}
-				return res;
-			}
-			return (knh_int_t)o1 - (knh_int_t)o2;
-		}
-		else {
-			return ctx->tStruct[bcid].fcompareTo(ctx, o1, o2);
-		}
-	}
-	else {
-		if((o1->h.cid == CLASS_Int || o1->h.cid == CLASS_Float)
-		&& (o2->h.cid == CLASS_Int || o2->h.cid == CLASS_Float)) {
-			return (int)(knh_Number_tofloat(o1) - knh_Number_tofloat(o2));
-		}
-		DBG2_P("Compared Incompatible Type %s - %s", CLASSN(o1->h.cid), CLASSN(o2->h.cid));
-		return (int)(o1 - o2);
-	}
-}
-
-/* ------------------------------------------------------------------------ */
-
-INLINE
-knh_bool_t knh_Object_equals(Ctx *ctx, Object *o1, Object *o2)
-{
-	return (knh_Object_compareTo(ctx, o1, o2) == 0);
-}
-
-
-/* ======================================================================== */
-/* [operators] */
-
 /* @method[CONST|NULLBASE] Boolean! Object.opEq(Any value) */
 
-METHOD knh__Object_opEq(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Object_opEq(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, knh_Object_compareTo(ctx,  sfp[0].o, sfp[1].o) == 0);
 }
@@ -127,7 +76,7 @@ METHOD knh__Object_opEq(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST|NULLBASE] Boolean! Object.opNeq(Any value) */
 
-METHOD knh__Object_opNeq(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Object_opNeq(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, knh_Object_compareTo(ctx,  sfp[0].o, sfp[1].o) != 0);
 }
@@ -135,7 +84,7 @@ METHOD knh__Object_opNeq(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST|NULLBASE] Boolean! Object.opLt(Any value) */
 
-METHOD knh__Object_opLt(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Object_opLt(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, knh_Object_compareTo(ctx, sfp[0].o, sfp[1].o) < 0);
 }
@@ -143,7 +92,7 @@ METHOD knh__Object_opLt(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST|NULLBASE] Boolean! Object.opLte(Any value) */
 
-METHOD knh__Object_opLte(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Object_opLte(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, knh_Object_compareTo(ctx, sfp[0].o, sfp[1].o) <= 0);
 }
@@ -151,7 +100,7 @@ METHOD knh__Object_opLte(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST|NULLBASE] Boolean! Object.opGt(Any value) */
 
-METHOD knh__Object_opGt(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Object_opGt(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, knh_Object_compareTo(ctx, sfp[0].o, sfp[1].o) > 0);
 }
@@ -159,7 +108,7 @@ METHOD knh__Object_opGt(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST|NULLBASE] Boolean! Object.opGte(Any value) */
 
-METHOD knh__Object_opGte(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Object_opGte(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, knh_Object_compareTo(ctx, sfp[0].o, sfp[1].o) >= 0);
 }
@@ -167,7 +116,7 @@ METHOD knh__Object_opGte(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Boolean! Object.opIs(Any v) */
 
-METHOD knh__Object_opIs(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Object_opIs(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_class_t scid = knh_Object_cid(sfp[0].o);
 	knh_class_t tcid = knh_Object_cid(sfp[1].o);
@@ -198,7 +147,7 @@ METHOD knh__Object_opIs(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Boolean! Object.opIsa(Class! c) */
 
-METHOD knh__Object_opIsa(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Object_opIsa(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_class_t scid = knh_Object_cid(sfp[0].o);
 	knh_class_t tcid = (sfp[1].c)->cid;
@@ -214,7 +163,7 @@ METHOD knh__Object_opIsa(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Boolean! Object.opTo(Class! c) */
 
-METHOD knh__Object_opTo(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Object_opTo(Ctx *ctx, knh_sfp_t *sfp)
 {
 	TODO_THROW(ctx);
 	KNH_RETURN_Boolean(ctx, sfp, 0);
@@ -223,7 +172,7 @@ METHOD knh__Object_opTo(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Class! Object.getClass() */
 
-METHOD knh__Object_getClass(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Object_getClass(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN(ctx, sfp, ctx->tClass[(sfp[0].o)->h.cid].class_cid);
 }
@@ -231,7 +180,7 @@ METHOD knh__Object_getClass(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST|NULLBASE] Boolean! Object.isNull() */
 
-METHOD knh__Object_isNull(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Object_isNull(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, IS_NULL(sfp[0].o));
 }
@@ -239,18 +188,15 @@ METHOD knh__Object_isNull(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST|NULLBASE] Boolean! Object.isNotNull() */
 
-METHOD knh__Object_isNotNull(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Object_isNotNull(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, IS_NOTNULL(sfp[0].o));
 }
 
-/* ======================================================================== */
-/* [mapping] */
-
 /* ------------------------------------------------------------------------ */
 /* @map Object Iterator! @Const */
 
-MAPPER knh_Object_Iterator(Ctx *ctx, knh_sfp_t *sfp)
+static MAPPER knh_Object_Iterator(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Object *o = sfp[0].o;
 	KNH_MAPPED(ctx, sfp, new_Iterator(ctx, o->h.cid, o, NULL));
@@ -259,18 +205,15 @@ MAPPER knh_Object_Iterator(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method This.. Object.opItr() */
 
-METHOD knh__Object_opItr(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Object_opItr(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN(ctx, sfp, new_Iterator(ctx, knh_Object_cid(sfp[0].o), sfp[0].o, NULL));
 }
 
 /* ------------------------------------------------------------------------ */
-/* ======================================================================== */
-/* [movabletext] */
-
 /* @method void Object.%s(OutputStream w, String m) */
 
-INLINE
+static
 void knh_Object__s(Ctx *ctx, Object *b, OutputStream *w, String *m)
 {
 	if(IS_NULL(b)) {
@@ -286,6 +229,7 @@ void knh_Object__s(Ctx *ctx, Object *b, OutputStream *w, String *m)
 /* ------------------------------------------------------------------------ */
 /* @method void Object.%k(OutputStream w, String m) */
 
+static
 void knh_Object__k(Ctx *ctx, Object *o, OutputStream *w, String *m)
 {
 	if(o->h.bcid == CLASS_Object) {
@@ -314,7 +258,7 @@ void knh_Object__k(Ctx *ctx, Object *o, OutputStream *w, String *m)
 /* ------------------------------------------------------------------------ */
 /* @method void Object.%dump(OutputStream w, String m) */
 
-INLINE
+static
 void knh_Object__dump(Ctx *ctx, Object *b, OutputStream *w, String *m)
 {
 	knh_class_t cid = knh_Object_cid(b);
@@ -346,16 +290,15 @@ void knh_Object__dump(Ctx *ctx, Object *b, OutputStream *w, String *m)
 /* ------------------------------------------------------------------------ */
 /* @method void Object.%empty(OutputStream w, String m) */
 
-INLINE
+static
 void knh_Object__empty(Ctx *ctx, Object *b, OutputStream *w, String *m)
 {
-
 }
 
 /* ------------------------------------------------------------------------ */
 /* @method void Object.%addr(OutputStream w, String m) */
 
-INLINE
+static
 void knh_Object__addr(Ctx *ctx, Object *b, OutputStream *w, String *m)
 {
 	knh_write__p(ctx, w, (void*)b);
@@ -364,6 +307,7 @@ void knh_Object__addr(Ctx *ctx, Object *b, OutputStream *w, String *m)
 /* ------------------------------------------------------------------------ */
 /* @map Object String! */
 
+static
 MAPPER knh_Object_String(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Object *o = sfp[0].o;
@@ -379,36 +323,21 @@ MAPPER knh_Object_String(Ctx *ctx, knh_sfp_t *sfp)
 	KNH_MAPPED(ctx, sfp, new_String__cwb(ctx, cwb));
 }
 
-/* ======================================================================== */
-/* [movabletext] */
-
-/* ------------------------------------------------------------------------ */
-/* @method void Nue.%s(OutputStream w, String m) */
-
-void knh_Nue__s(Ctx *ctx, Nue *b, OutputStream *w, String *m)
-{
-
-}
-
 /* ------------------------------------------------------------------------ */
 /* @method void Nue.%k(OutputStream w, String m) */
 
+static
 void knh_Nue__k(Ctx *ctx, Nue *b, OutputStream *w, String *m)
 {
 	knh_write(ctx, w, knh_String_tobytes(TS_null));
 }
 
-/* ======================================================================== */
-/* [mapping] */
-
 /* ======================================================================== */
 /* [Class] */
 
-/* ======================================================================== */
-/* [movabletext] */
-
 /* @method void Class.%s(OutputStream w, String m) */
 
+static
 void knh_Class__s(Ctx *ctx, Class *o, OutputStream *w, String *m)
 {
 	knh_write_cid(ctx, w, o->cid);
@@ -417,6 +346,7 @@ void knh_Class__s(Ctx *ctx, Class *o, OutputStream *w, String *m)
 /* ------------------------------------------------------------------------ */
 /* @method void Class.%k(OutputStream w, String m) */
 
+static
 void knh_Class__k(Ctx *ctx, Class *o, OutputStream *w, String *m)
 {
 	knh_write_type(ctx, w, o->type);
@@ -425,6 +355,7 @@ void knh_Class__k(Ctx *ctx, Class *o, OutputStream *w, String *m)
 /* ------------------------------------------------------------------------ */
 /* @method void Class.%dump(OutputStream w, String m) */
 
+static
 void knh_Class__dump(Ctx *ctx, Class *o, OutputStream *w, String *m)
 {
 	TODO_THROW(ctx);
@@ -562,6 +493,7 @@ void knh_Method__man(Ctx *ctx, Method *o, OutputStream *w, knh_class_t cid)
 /* ------------------------------------------------------------------------ */
 /* @method void Class.%man(OutputStream w, String m) */
 
+static
 void knh_Class__man(Ctx *ctx, Class *o, OutputStream *w, String *m)
 {
 	knh_class_t cid = (o)->cid;
@@ -684,7 +616,6 @@ void knh_Class__man(Ctx *ctx, Class *o, OutputStream *w, String *m)
 }
 
 /* ======================================================================== */
-/* [Method] */
 
 /* ------------------------------------------------------------------------ */
 /* @method void Method.%s(OutputStream w, String m) */
@@ -736,7 +667,6 @@ void knh_Method__k(Ctx *ctx, Method *o, OutputStream *w, String *m)
 /* ------------------------------------------------------------------------ */
 /* @method void Method.%dump(OutputStream w, String m) */
 
-
 void knh_Method__dump(Ctx *ctx, Method *o, OutputStream *w, String *m)
 {
 	knh_Method__k(ctx, o, w, m);
@@ -748,6 +678,9 @@ void knh_Method__dump(Ctx *ctx, Method *o, OutputStream *w, String *m)
 	}
 }
 
+/* ------------------------------------------------------------------------ */
+
+#endif /*KNH_CC_METHODAPI*/
 
 /* ------------------------------------------------------------------------ */
 
