@@ -153,6 +153,49 @@ knh_hcode_t knh_Object_hashCode(Ctx *ctx, Object *o)
 	return ctx->tStruct[o->h.bcid].fhashCode(ctx, o);
 }
 
+/* ------------------------------------------------------------------------ */
+
+INLINE
+int knh_Object_compareTo(Ctx *ctx, Object *o1, Object *o2)
+{
+	knh_class_t bcid = o1->h.bcid;
+	knh_class_t bcid2 = o2->h.bcid;
+	if(bcid == bcid2) {
+		if(bcid == CLASS_Object) {
+			int idx = ctx->tClass[o1->h.cid].keyidx;
+			if(idx != -1) {
+				int res = knh_Object_compareTo(ctx, KNH_FIELDn(o1, idx), KNH_FIELDn(o2, idx));
+				if(res == 0) return res;
+				idx = ctx->tClass[o1->h.cid].keyidx2;
+				if(idx != -1) {
+					return knh_Object_compareTo(ctx, KNH_FIELDn(o1, idx), KNH_FIELDn(o2, idx));
+				}
+				return res;
+			}
+			return (knh_int_t)o1 - (knh_int_t)o2;
+		}
+		else {
+			return ctx->tStruct[bcid].fcompareTo(ctx, o1, o2);
+		}
+	}
+	else {
+		if((o1->h.cid == CLASS_Int || o1->h.cid == CLASS_Float)
+		&& (o2->h.cid == CLASS_Int || o2->h.cid == CLASS_Float)) {
+			return (int)(knh_Number_tofloat(o1) - knh_Number_tofloat(o2));
+		}
+		DBG2_P("Compared Incompatible Type %s - %s", CLASSN(o1->h.cid), CLASSN(o2->h.cid));
+		return (int)(o1 - o2);
+	}
+}
+
+/* ------------------------------------------------------------------------ */
+
+INLINE
+knh_bool_t knh_Object_equals(Ctx *ctx, Object *o1, Object *o2)
+{
+	return (knh_Object_compareTo(ctx, o1, o2) == 0);
+}
+
 
 /* ------------------------------------------------------------------------ */
 
