@@ -252,6 +252,65 @@ KNHAPI(void) knh_ResultSet_setNULL(Ctx *ctx, ResultSet *o, size_t n)
 	DP(o)->column[n].len = 0;
 }
 
+/* ------------------------------------------------------------------------ */
+
+knh_integer_t knh_ResultSet_getInt(Ctx *ctx, ResultSet *o, size_t n)
+{
+	KNH_ASSERT(n < DP(o)->column_size);
+	char *p = knh_Bytes_tochar(DP(o)->databuf) + DP(o)->column[n].start;
+	switch(DP(o)->column[n].ctype) {
+	case knh_ResultSet_CTYPE__null :
+		return 0;
+	case knh_ResultSet_CTYPE__integer :
+		return (knh_integer_t)(*((knh_integer_t*)p));
+	case knh_ResultSet_CTYPE__float :
+		return (knh_integer_t)(*((knh_float_t*)p));
+	case knh_ResultSet_CTYPE__bytes :
+		TODO();
+//		return knh_bytes_toint(B2(p, DP(o)->column[n].len));
+	}
+	return 0;
+}
+
+/* ------------------------------------------------------------------------ */
+
+knh_float_t knh_ResultSet_getFloat(Ctx *ctx, ResultSet *o, size_t n)
+{
+	KNH_ASSERT(n < DP(o)->column_size);
+	char *p = knh_Bytes_tochar(DP(o)->databuf) + DP(o)->column[n].start;
+	switch(DP(o)->column[n].ctype) {
+	case knh_ResultSet_CTYPE__null :
+		return 0.0;
+	case knh_ResultSet_CTYPE__integer :
+		return (knh_float_t)(*((knh_integer_t*)p));
+	case knh_ResultSet_CTYPE__float :
+		return (knh_float_t)(*((knh_float_t*)p));
+	case knh_ResultSet_CTYPE__bytes :
+		TODO();
+//		return knh_bytes_tofloat(B2(p, DP(o)->column[n].len));
+	}
+	return 0.0;
+}
+
+/* ------------------------------------------------------------------------ */
+
+String* knh_ResultSet_getString(Ctx *ctx, ResultSet *o, size_t n)
+{
+	KNH_ASSERT(n < DP(o)->column_size);
+	char *p = knh_Bytes_tochar(DP(o)->databuf) + DP(o)->column[n].start;
+	switch(DP(o)->column[n].ctype) {
+	case knh_ResultSet_CTYPE__null :
+		return (String*)KNH_NULL;
+	case knh_ResultSet_CTYPE__integer :
+		return new_String__integer(ctx, (knh_integer_t)(*((knh_integer_t*)p)));
+	case knh_ResultSet_CTYPE__float :
+		return new_String__float(ctx, (knh_float_t)(*((knh_float_t*)p)));
+	case knh_ResultSet_CTYPE__text :
+		return new_String(ctx, B2(p, DP(o)->column[n].len), NULL);
+	}
+	return (String*)KNH_NULL;
+}
+
 /* ======================================================================== */
 
 
