@@ -1984,7 +1984,7 @@ void knh_StmtFOREACH_asm(Ctx *ctx, Stmt *stmt, Asm *abr)
 
 	TERMs_asm(ctx, stmt, FOREACH_iter, abr, NNTYPE_Iterator, DP(tkitr)->index);
 	KNH_ASM_GLABEL(ctx, abr, lbbegin);
-	//DBG2_P("**(%d)ntype=%s%s (%d)itrtype=%s%s **", DP(tkn)->index, TYPEQN(DP(tkn)->type), DP(tkitr)->index, TYPEQN(DP(tkitr)->type));
+	DBG2_P("**(%d)ntype=%s%s (%d)itrtype=%s%s **", DP(tkn)->index, TYPEQN(DP(tkn)->type), DP(tkitr)->index, TYPEQN(DP(tkitr)->type));
 	knh_class_t ncid = CLASS_type(DP(tkn)->type);
 	knh_class_t itrcid = CLASS_type(DP(tkitr)->type);
 	KNH_ASSERT_cid(itrcid); itrcid = ctx->tClass[itrcid].p1;
