@@ -682,14 +682,14 @@ void konohac_eval(Ctx *ctx, String *nsname, InputStream *in)
 
 Stmt *konoha_parse(Ctx *ctx, char *kscript)
 {
-	knh_wbuf_t cwb = knh_Context_wbuf(ctx);
+	knh_cwb_t cwb = new_cwb(ctx);
 	knh_Bytes_write(ctx, cwb.ba, B(kscript));
 	knh_Bytes_putc(ctx, cwb.ba, ';');
 	InputStream *in = new_BytesInputStream(ctx, cwb.ba, cwb.pos, knh_Bytes_size(cwb.ba));
 	DP(in)->fileid = 0;
 	DP(in)->line = 0;
 	Stmt *stmt = konohac_parse(ctx, in);
-	knh_Bytes_subclear(cwb.ba, cwb.pos);
+	knh_cwb_clear(cwb);
 	return stmt;
 }
 
