@@ -1589,6 +1589,12 @@ Term *knh_StmtINVOKE_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 	knh_class_t cid = TERMs_getcid(stmt, 0);
 	KNH_ASSERT_cid(cid); DBG2_ASSERT(knh_type_isClosure(ctx, cid));
 	/* 0 1 2 3 4 .. 5 */
+	Method *mtd = knh_Class_getMethod(ctx, CLASS_Closure, METHODN_invoke);
+	knh_Token_toMTD(ctx, DP(stmt)->tokens[1], METHODN_invoke, mtd);
+	Token *tktemp = DP(stmt)->tokens[0];
+	DP(stmt)->tokens[0] = DP(stmt)->tokens[1];
+	DP(stmt)->tokens[1] = tktemp;
+
 	if(cid == CLASS_Closure /* || DP(stmt)->size > 4 */) {
 		size_t i;
 		for(i = 0; i < DP(stmt)->size; i++) {
@@ -1599,6 +1605,7 @@ Term *knh_StmtINVOKE_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 		knh_Stmt_setType(ctx, stmt, TYPE_Any);
 		return TM(stmt);
 	}
+
 	knh_Stmt_setType(ctx, stmt, ctx->tClass[cid].r0);
 
 	if(ctx->tClass[cid].p1 != TYPE_void) {
@@ -1641,7 +1648,6 @@ Term *knh_StmtINVOKE_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 		DP(stmt)->size = 4;
 		return TM(stmt);
 	}
-
 }
 
 /* ------------------------------------------------------------------------- */
@@ -1774,7 +1780,6 @@ Term *knh_StmtCALLBASE_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh
 		knh_format_methodn(ctx, bufmn, sizeof(bufmn), mn);
 		//DEBUG3("0. lookup closure..");
 		if(knh_TokenNAME_isClosure(ctx, DP(stmt)->tokens[0], abr)) {
-			SP(stmt)->stt = STT_INVOKE;
 			return knh_StmtINVOKE_typing(ctx, stmt, abr, ns);
 		}
 
@@ -2085,6 +2090,14 @@ Term *knh_StmtOP_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_type_
 			return NULL;
 		}
 		if(TERMs_isNULL(stmt, 1)) {
+			Term *temp = DP(stmt)->terms[1];
+			DP(stmt)->terms[1] = DP(stmt)->terms[2];
+			DP(stmt)->terms[2] = temp;
+		}
+		if(TERMs_isNULL(stmt, 2)) {
+			if(IS_NNTYPE(TERMs_gettype(stmt,1))) {
+				return TM(new_TokenCONST(ctx, FL(stmt), KNH_FALSE));
+			}
 			mn = METHODN_isNull;
 			mtd_cid = CLASS_Object;
 			DP(stmt)->size = 2;
@@ -2104,6 +2117,14 @@ Term *knh_StmtOP_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_type_
 			return NULL;
 		}
 		if(TERMs_isNULL(stmt, 1)) {
+			Term *temp = DP(stmt)->terms[1];
+			DP(stmt)->terms[1] = DP(stmt)->terms[2];
+			DP(stmt)->terms[2] = temp;
+		}
+		if(TERMs_isNULL(stmt, 2)) {
+			if(IS_NNTYPE(TERMs_gettype(stmt,1))) {
+				return TM(new_TokenCONST(ctx, FL(stmt), KNH_TRUE));
+			}
 			mn = METHODN_isNotNull;
 			mtd_cid = CLASS_Object;
 			DP(stmt)->size = 2;
@@ -2799,7 +2820,7 @@ Term *knh_StmtRETURN_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 			DP(stmt)->size = 0;
 		}
 	}
-	else if(knh_Method_isNew(ctx, DP(abr)->mtd)) {
+	else if(knh_Method_isConstructor(ctx, DP(abr)->mtd)) {
 		if(DP(stmt)->size > 0) {
 			knh_Asm_perror(ctx, abr, KMSG_IGRETURN, NULL);
 			DP(stmt)->size = 1;
@@ -3020,7 +3041,7 @@ int knh_Stmt_checkLastReturn(Ctx *ctx, Stmt *stmt, Method *mtd)
 
 	/* Generate default return statement */
 	Stmt *rstmt = new_Stmt(ctx, 0, STT_RETURN);
-	if(knh_Method_isNew(ctx, mtd) || knh_Method_rztype(mtd) == TYPE_void) {
+	if(knh_Method_isConstructor(ctx, mtd) || knh_Method_rztype(mtd) == TYPE_void) {
 		//last_stmt = knh_StmtNULL_tail_append(ctx, last_stmt, rstmt);
 	}
 	else { /* return default value */
