@@ -40,6 +40,65 @@
 extern "C" {
 #endif
 
+
+/* ======================================================================== */
+/* [ctxkey] */
+
+static int isInit = 0;
+
+#ifdef KNH_USING_NOTHREAD
+static Ctx *curctx = NULL;
+#else
+static knh_thread_key_t ctxkey;
+#endif
+
+/* ------------------------------------------------------------------------ */
+
+void konoha_init(void)
+{
+#ifndef KNH_USING_NOTHREAD
+	if(isInit == 0) {
+		isInit = 1;
+		knh_thread_key_create(&ctxkey);
+	}
+#endif
+	isInit = 1;
+}
+
+/* ------------------------------------------------------------------------ */
+
+static
+void konoha_setCurrentContext(Ctx *ctx)
+{
+#ifdef KNH_USING_NOTHREAD
+	curctx = ctx;
+#else
+	if(ctx == NULL) {
+		knh_thread_getspecific(ctxkey, NULL);
+	}
+	else {
+		if(knh_thread_getspecific(ctxkey) != NULL) {
+			KNH_WARNING(ctx, "Mixed context!! in the same thread");
+			return;
+		}
+		knh_thread_setspecific(ctxkey, NULL);
+	}
+#endif
+}
+
+/* ------------------------------------------------------------------------ */
+
+KNHAPI(Ctx*) konoha_getCurrentContext(void)
+{
+#ifdef KNH_USING_NOTHREAD
+	return curctx;
+#else
+	Ctx *ctx = (Ctx*)knh_thread_getspecific(ctxkey);
+	KNH_ASSERT(ctx != NULL);
+	return ctx;
+#endif
+}
+
 /* ======================================================================== */
 /* [option] */
 
@@ -91,36 +150,38 @@ KNHAPI(char*) konoha_eval(konoha_t konoha, char *script)
 {
 	KONOHA_CHECK(konoha, NULL);
 	Ctx *ctx = konoha.ctx;
-	knh_sfp_t *lsfp = KNH_LOCAL(ctx);
-	knh_cwb_t cwb = new_cwb(ctx);
-	knh_Bytes_write(ctx, cwb.ba, B(script));
-	knh_Bytes_putc(ctx, cwb.ba, ';');
-	knh_Bytes_putc(ctx, cwb.ba, '\n');
-	InputStream *in = new_BytesInputStream(ctx, cwb.ba, cwb.pos, knh_Bytes_size(cwb.ba));
-	KNH_LPUSH(ctx, in);
-	DP(in)->fileid = knh_tName_getFileId(ctx, STEXT("(eval)"));
-	DP(in)->line = 0;
+	Bytes *ba = NULL;
+	konoha_setCurrentContext(ctx);
+	{
+		knh_sfp_t *lsfp = KNH_LOCAL(ctx);
+		knh_cwb_t cwb = new_cwb(ctx);
+		knh_Bytes_write(ctx, cwb.ba, B(script));
+		knh_Bytes_putc(ctx, cwb.ba, ';');
+		knh_Bytes_putc(ctx, cwb.ba, '\n');
+		InputStream *in = new_BytesInputStream(ctx, cwb.ba, cwb.pos, knh_Bytes_size(cwb.ba));
+		KNH_LPUSH(ctx, in);
+		DP(in)->fileid = knh_tName_getFileId(ctx, STEXT("(eval)"));
+		DP(in)->line = 0;
 
-	Bytes *ba = new_Bytes(ctx, 1024);
-	OutputStream *out = new_BytesOutputStream(ctx, ba);
-	KNH_LPUSH(ctx, out);
-	KNH_SETv(ctx, ((Context*)ctx)->out, out);
-	KNH_SETv(ctx, ((Context*)ctx)->err, out);
+		ba = new_Bytes(ctx, 1024);
+		OutputStream *out = new_BytesOutputStream(ctx, ba);
+		KNH_LPUSH(ctx, out);
+		KNH_SETv(ctx, ((Context*)ctx)->out, out);
+		KNH_SETv(ctx, ((Context*)ctx)->err, out);
 
-	konohac_eval(ctx, TS_main, in);
-	knh_cwb_clear(cwb);
-	knh_OutputStream_flush(ctx, out);
-	KNH_LOCALBACK(ctx, lsfp);
+		konohac_eval(ctx, TS_main, in);
+		knh_cwb_clear(cwb);
+		knh_OutputStream_flush(ctx, out);
+		KNH_LOCALBACK(ctx, lsfp);
+	}
+	konoha_setCurrentContext(NULL);
 	return (char*)ba->buf;
 }
 
 /* ------------------------------------------------------------------------ */
 
-KNHAPI(void) konoha_read(konoha_t konoha, char *fpath)
+KNHAPI(void) konoha_readFile(Ctx *ctx, char *fpath)
 {
-	KONOHA_CHECK_(konoha);
-	Ctx *ctx = konoha.ctx;
-	if(ctx == NULL) return;
 	if(!knh_isfile(ctx, B(fpath))) {
 		KNH_WARNING(ctx, "No such file: %s\n", fpath);
 		return ;
@@ -137,10 +198,23 @@ KNHAPI(void) konoha_read(konoha_t konoha, char *fpath)
 
 /* ------------------------------------------------------------------------ */
 
+KNHAPI(void) konoha_read(konoha_t konoha, char *fpath)
+{
+	KONOHA_CHECK_(konoha);
+	konoha_setCurrentContext(konoha.ctx);
+	{
+		konoha_readFile(konoha.ctx, fpath);
+	}
+	konoha_setCurrentContext(NULL);
+}
+
+/* ------------------------------------------------------------------------ */
+
 KNHAPI(int) konoha_main(konoha_t konoha, int argc, char **argv)
 {
 	KONOHA_CHECK(konoha, 0);
 	Ctx *ctx = konoha.ctx;
+	konoha_setCurrentContext(ctx);
 	knh_sfp_t *lsfp = KNH_LOCAL(ctx);
 	KNH_MOV(ctx, lsfp[0].o, new_ExceptionHandler(ctx));
 	KNH_TRY(ctx, L_CATCH, lsfp, 0);
@@ -177,11 +251,13 @@ KNHAPI(int) konoha_main(konoha_t konoha, int argc, char **argv)
 	}
 	L_END_TRY:
 	knh_Context_clearstack(ctx);
+	konoha_setCurrentContext(NULL);
 	return 0;
 
 	/* catch */
 	L_CATCH:;
 	KNH_PRINT_STACKTRACE(ctx, lsfp, 0);
+	konoha_setCurrentContext(NULL);
 	return 0;
 }
 
@@ -270,86 +346,90 @@ KNHAPI(void) konoha_shell(konoha_t konoha)
 {
 	KONOHA_CHECK_(konoha);
 	Ctx *ctx = konoha.ctx;
-	knh_System__dump(ctx, NULL, KNH_STDOUT, (String*)KNH_NULL);
-	int linenum, linecnt = 0;
-	knh_cwb_t cwb = new_cwb(ctx);
-	char *ln = NULL;
-	knh_sfp_t *lsfp = KNH_LOCAL(ctx);
-	KNH_LPUSH(ctx, KNH_NULL);  // step esp++;
+	konoha_setCurrentContext(ctx);
+	{
+		knh_System__dump(ctx, NULL, KNH_STDOUT, (String*)KNH_NULL);
+		int linenum, linecnt = 0;
+		knh_cwb_t cwb = new_cwb(ctx);
+		char *ln = NULL;
+		knh_sfp_t *lsfp = KNH_LOCAL(ctx);
+		KNH_LPUSH(ctx, KNH_NULL);  // step esp++;
 
-	START_LINE:;
-	if(ln != NULL) free(ln);
+		START_LINE:;
+		if(ln != NULL) free(ln);
 #ifdef KNH_DBGMODE
-	ln = knh_readline("\n>>> ");
+		ln = knh_readline("\n>>> ");
 #else
-	ln = knh_readline(">>> ");
+		ln = knh_readline(">>> ");
 #endif
-	linecnt++;
-	linenum = linecnt;
+		linecnt++;
+		linenum = linecnt;
 
-	while(1) {
-		int nest = 0;
-		if(ln == NULL) {
-			KNH_LOCALBACK(ctx, lsfp);
-			knh_Context_clearstack(ctx);
-			return;
+		while(1) {
+			int nest = 0;
+			if(ln == NULL) {
+				KNH_LOCALBACK(ctx, lsfp);
+				knh_Context_clearstack(ctx);
+				return;
+			}
+			knh_Bytes_write(ctx, cwb.ba, B(ln));
+			nest = konoha_shell_checkline(knh_cwb_tobytes(cwb));
+			if(nest == 0) break;
+			if(nest < 0) {
+				knh_println(ctx, KNH_STDOUT, STEXT("(Canceled)"));
+				knh_cwb_clear(cwb);
+				goto START_LINE;
+			}else {
+				knh_Bytes_putc(ctx, cwb.ba, '\n');
+				if(ln != NULL) free(ln);
+				ln = knh_readline("... ");
+				linecnt++;
+			}
 		}
-		knh_Bytes_write(ctx, cwb.ba, B(ln));
-		nest = konoha_shell_checkline(knh_cwb_tobytes(cwb));
-		if(nest == 0) break;
-		if(nest < 0) {
-			knh_println(ctx, KNH_STDOUT, STEXT("(Canceled)"));
-			knh_cwb_clear(cwb);
-			goto START_LINE;
-		}else {
+		if(cwb.pos < knh_Bytes_size(cwb.ba)) {
+			knh_bytes_t t = knh_cwb_tobytes(cwb);
+			if(ISB(t, "exit") || ISB(t, "quit") || ISB(t, "bye")) {
+				if(ln != NULL) free(ln);
+				knh_cwb_clear(cwb);
+				KNH_LOCALBACK(ctx, lsfp);
+				knh_Context_clearstack(ctx);
+				konoha_setCurrentContext(NULL);
+				return;
+			}
+			if(knh_bytes_startsWith(t, STEXT("man "))) {
+				char bufc[CLASSNAME_BUFSIZ], *p = bufc;
+				knh_snprintf(bufc, sizeof(bufc), "%%man(%s)", (char*)knh_bytes_last(t, 4).buf);
+				while(*p != 0) {
+					if(*p == ';') *p = ' ';
+					p++;
+				}
+				knh_cwb_clear(cwb);
+				knh_Bytes_write(ctx, cwb.ba, B(bufc));
+			}
+			else if(knh_bytes_startsWith(t, STEXT("dump "))) {
+				char bufc[CLASSNAME_BUFSIZ], *p = bufc;
+				knh_snprintf(bufc, sizeof(bufc), "%%dump(%s)", (char*)knh_bytes_last(t, 5).buf);
+				while(*p != 0) {
+					if(*p == ';') *p = ' ';
+					p++;
+				}
+				knh_cwb_clear(cwb);
+				knh_Bytes_write(ctx, cwb.ba, B(bufc));
+			}
+			knh_Bytes_putc(ctx, cwb.ba, ';');
 			knh_Bytes_putc(ctx, cwb.ba, '\n');
-			if(ln != NULL) free(ln);
-			ln = knh_readline("... ");
-			linecnt++;
-		}
-	}
-	if(cwb.pos < knh_Bytes_size(cwb.ba)) {
-		knh_bytes_t t = knh_cwb_tobytes(cwb);
-		if(ISB(t, "exit") || ISB(t, "quit") || ISB(t, "bye")) {
-			if(ln != NULL) free(ln);
-			knh_cwb_clear(cwb);
-			KNH_LOCALBACK(ctx, lsfp);
-			knh_Context_clearstack(ctx);
-			return;
-		}
-		if(knh_bytes_startsWith(t, STEXT("man "))) {
-			char bufc[CLASSNAME_BUFSIZ], *p = bufc;
-			knh_snprintf(bufc, sizeof(bufc), "%%man(%s)", (char*)knh_bytes_last(t, 4).buf);
-			while(*p != 0) {
-				if(*p == ';') *p = ' ';
-				p++;
+			{
+				InputStream *in = new_BytesInputStream(ctx, cwb.ba, cwb.pos, knh_Bytes_size(cwb.ba));
+				KNH_MOV(ctx, lsfp[0].o, in);
+				DP(in)->fileid = knh_tName_getFileId(ctx, STEXT("(shell)"));
+				DP(in)->line = linenum;
+				knh_InputStream_setEncoding(ctx, in, knh_systemEncoding);
+				konohac_eval(ctx, TS_main, in);
+				knh_cwb_clear(cwb);
 			}
-			knh_cwb_clear(cwb);
-			knh_Bytes_write(ctx, cwb.ba, B(bufc));
-		}
-		else if(knh_bytes_startsWith(t, STEXT("dump "))) {
-			char bufc[CLASSNAME_BUFSIZ], *p = bufc;
-			knh_snprintf(bufc, sizeof(bufc), "%%dump(%s)", (char*)knh_bytes_last(t, 5).buf);
-			while(*p != 0) {
-				if(*p == ';') *p = ' ';
-				p++;
-			}
-			knh_cwb_clear(cwb);
-			knh_Bytes_write(ctx, cwb.ba, B(bufc));
-		}
-		knh_Bytes_putc(ctx, cwb.ba, ';');
-		knh_Bytes_putc(ctx, cwb.ba, '\n');
-		{
-			InputStream *in = new_BytesInputStream(ctx, cwb.ba, cwb.pos, knh_Bytes_size(cwb.ba));
-			KNH_MOV(ctx, lsfp[0].o, in);
-			DP(in)->fileid = knh_tName_getFileId(ctx, STEXT("(shell)"));
-			DP(in)->line = linenum;
-			knh_InputStream_setEncoding(ctx, in, knh_systemEncoding);
-			konohac_eval(ctx, TS_main, in);
-			knh_cwb_clear(cwb);
 		}
+		goto START_LINE;
 	}
-	goto START_LINE;
 }
 
 /* ======================================================================== */
@@ -422,7 +502,6 @@ METHOD knh__Script_addHistory(Ctx *ctx, knh_sfp_t *sfp)
 }
 
 /* ------------------------------------------------------------------------ */
-/* ------------------------------------------------------------------------ */
 
 
 #ifdef __cplusplus
