@@ -79,6 +79,15 @@ typedef struct {
 	knh_class_t p2;
 } knh_GenericsData_t ;
 
+typedef struct {
+	char *name;
+	knh_class_t cid;
+	knh_type_t r0;
+	knh_type_t p1;
+	knh_type_t p2;
+	knh_type_t p3;
+} knh_ClosureData_t ;
+
 typedef struct {
 	char *name;
 	knh_flag_t flag;
@@ -2349,6 +2358,19 @@ Object *knh_System_fdefault(Ctx *ctx, knh_class_t cid)
 
 #define KNH_CC_METHODAPI
 #include"../gen/method_.c"
+#include"../api/objectapi.c"
+#include"../api/numberapi.c"
+#include"../api/stringapi.c"
+
+#include"../api/bytesapi.c"
+#include"../api/arrayapi.c"
+#include"../api/dictapi.c"
+#include"../api/hashapi.c"
+
+#include"../api/systemapi.c"
+#include"../api/streamapi.c"
+#include"../api/dbapi.c"
+
 #include<konoha/gen/struct_.h>
 
 #ifdef __cplusplus
@@ -2532,6 +2554,17 @@ void konoha_loadGenericsData(Ctx *ctx, knh_GenericsData_t *data)
 
 /* ------------------------------------------------------------------------ */
 
+static
+void konoha_loadClosureData(Ctx *ctx, knh_ClosureData_t *data)
+{
+	while(data->name != NULL) {
+		konoha_addClosureClass(ctx, data->cid, new_String__T(ctx, data->name), data->r0, data->p1, data->p2, data->p3);
+		data++;
+	}
+}
+
+/* ------------------------------------------------------------------------ */
+
 static
 void konoha_loadExptData(Ctx *ctx, knh_ExptData_t *data)
 {
@@ -2596,7 +2629,7 @@ void konoha_loadMethodFieldData(Ctx *ctx, knh_MethodFieldData_t *data)
 			mf->params[4].fn = data->f4;
 		}
 		knh_tMethodField_add(ctx, mf);
-		KNH_ASSERT(knh_tMethodField(ctx, data->mfindex) == mf);
+		DBG2_ASSERT(knh_tMethodField(ctx, data->mfindex) == mf);
 		data++;
 	}
 }
@@ -2742,13 +2775,15 @@ void konoha_loadSystemData(Ctx *ctx)
 	konoha_loadStructData(ctx, StructData);
 	konoha_initContext(ctx, (Context*)ctx, ctx->stacksize);
 	konoha_loadClassData(ctx, ClassData);
+	konoha_loadMethodFieldData(ctx, MethodFieldData);
+
 	konoha_loadClassProperties(ctx);
 	konoha_loadGenericsData(ctx, GenericsData);
+	konoha_loadClosureData(ctx, ClosureData);
 	konoha_loadExptData(ctx, ExptData);
 	konoha_loadFuncData(ctx, FuncData);
 
 	konoha_loadFieldNameData(ctx, FieldNameData);
-	konoha_loadMethodFieldData(ctx, MethodFieldData);
 	konoha_loadMethodData(ctx, MethodData);
 	konoha_loadMapperData(ctx, MapperData);
 
